import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { ChimeSDKIdentityClientResolvedConfig } from "../ChimeSDKIdentityClient";
/**
 * @internal
 */
export interface ChimeSDKIdentityHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface ChimeSDKIdentityHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<ChimeSDKIdentityClientResolvedConfig, HandlerExecutionContext, ChimeSDKIdentityHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultChimeSDKIdentityHttpAuthSchemeParametersProvider: (config: ChimeSDKIdentityClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<ChimeSDKIdentityHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface ChimeSDKIdentityHttpAuthSchemeProvider extends HttpAuthSchemeProvider<ChimeSDKIdentityHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultChimeSDKIdentityHttpAuthSchemeProvider: ChimeSDKIdentityHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: ChimeSDKIdentityHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: ChimeSDKIdentityHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
