import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ChimeSDKMediaPipelinesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../ChimeSDKMediaPipelinesClient";
import { UpdateMediaPipelineKinesisVideoStreamPoolRequest, UpdateMediaPipelineKinesisVideoStreamPoolResponse } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link UpdateMediaPipelineKinesisVideoStreamPoolCommand}.
 */
export interface UpdateMediaPipelineKinesisVideoStreamPoolCommandInput extends UpdateMediaPipelineKinesisVideoStreamPoolRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateMediaPipelineKinesisVideoStreamPoolCommand}.
 */
export interface UpdateMediaPipelineKinesisVideoStreamPoolCommandOutput extends UpdateMediaPipelineKinesisVideoStreamPoolResponse, __MetadataBearer {
}
declare const UpdateMediaPipelineKinesisVideoStreamPoolCommand_base: {
    new (input: UpdateMediaPipelineKinesisVideoStreamPoolCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateMediaPipelineKinesisVideoStreamPoolCommandInput, UpdateMediaPipelineKinesisVideoStreamPoolCommandOutput, ChimeSDKMediaPipelinesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: UpdateMediaPipelineKinesisVideoStreamPoolCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateMediaPipelineKinesisVideoStreamPoolCommandInput, UpdateMediaPipelineKinesisVideoStreamPoolCommandOutput, ChimeSDKMediaPipelinesClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates an Kinesis video stream pool in a media pipeline.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { ChimeSDKMediaPipelinesClient, UpdateMediaPipelineKinesisVideoStreamPoolCommand } from "@aws-sdk/client-chime-sdk-media-pipelines"; // ES Modules import
 * // const { ChimeSDKMediaPipelinesClient, UpdateMediaPipelineKinesisVideoStreamPoolCommand } = require("@aws-sdk/client-chime-sdk-media-pipelines"); // CommonJS import
 * const client = new ChimeSDKMediaPipelinesClient(config);
 * const input = { // UpdateMediaPipelineKinesisVideoStreamPoolRequest
 *   Identifier: "STRING_VALUE", // required
 *   StreamConfiguration: { // KinesisVideoStreamConfigurationUpdate
 *     DataRetentionInHours: Number("int"),
 *   },
 * };
 * const command = new UpdateMediaPipelineKinesisVideoStreamPoolCommand(input);
 * const response = await client.send(command);
 * // { // UpdateMediaPipelineKinesisVideoStreamPoolResponse
 * //   KinesisVideoStreamPoolConfiguration: { // KinesisVideoStreamPoolConfiguration
 * //     PoolArn: "STRING_VALUE",
 * //     PoolName: "STRING_VALUE",
 * //     PoolId: "STRING_VALUE",
 * //     PoolStatus: "CREATING" || "ACTIVE" || "UPDATING" || "DELETING" || "FAILED",
 * //     PoolSize: Number("int"),
 * //     StreamConfiguration: { // KinesisVideoStreamConfiguration
 * //       Region: "STRING_VALUE", // required
 * //       DataRetentionInHours: Number("int"),
 * //     },
 * //     CreatedTimestamp: new Date("TIMESTAMP"),
 * //     UpdatedTimestamp: new Date("TIMESTAMP"),
 * //   },
 * // };
 *
 * ```
 *
 * @param UpdateMediaPipelineKinesisVideoStreamPoolCommandInput - {@link UpdateMediaPipelineKinesisVideoStreamPoolCommandInput}
 * @returns {@link UpdateMediaPipelineKinesisVideoStreamPoolCommandOutput}
 * @see {@link UpdateMediaPipelineKinesisVideoStreamPoolCommandInput} for command's `input` shape.
 * @see {@link UpdateMediaPipelineKinesisVideoStreamPoolCommandOutput} for command's `response` shape.
 * @see {@link ChimeSDKMediaPipelinesClientResolvedConfig | config} for ChimeSDKMediaPipelinesClient's `config` shape.
 *
 * @throws {@link BadRequestException} (client fault)
 *  <p>The input parameters don't match the service's restrictions.</p>
 *
 * @throws {@link ConflictException} (client fault)
 *  <p>The request could not be processed because of conflict in the current state of the
 *          resource.</p>
 *
 * @throws {@link ForbiddenException} (client fault)
 *  <p>The client is permanently forbidden from making the request.</p>
 *
 * @throws {@link NotFoundException} (client fault)
 *  <p>One or more of the resources in the request does not exist in the system.</p>
 *
 * @throws {@link ServiceFailureException} (server fault)
 *  <p>The service encountered an unexpected error.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service is currently unavailable.</p>
 *
 * @throws {@link ThrottledClientException} (client fault)
 *  <p>The client exceeded its request rate limit.</p>
 *
 * @throws {@link UnauthorizedClientException} (client fault)
 *  <p>The client is not currently authorized to make the request.</p>
 *
 * @throws {@link ChimeSDKMediaPipelinesServiceException}
 * <p>Base exception class for all service exceptions from ChimeSDKMediaPipelines service.</p>
 *
 * @public
 */
export declare class UpdateMediaPipelineKinesisVideoStreamPoolCommand extends UpdateMediaPipelineKinesisVideoStreamPoolCommand_base {
}
