import { ExceptionOptionType as __ExceptionOptionType } from "@smithy/smithy-client";
import { ChimeSDKVoiceServiceException as __BaseException } from "./ChimeSDKVoiceServiceException";
/**
 * @public
 * @enum
 */
export declare const ErrorCode: {
    readonly AccessDenied: "AccessDenied";
    readonly BadRequest: "BadRequest";
    readonly Conflict: "Conflict";
    readonly Forbidden: "Forbidden";
    readonly Gone: "Gone";
    readonly NotFound: "NotFound";
    readonly PhoneNumberAssociationsExist: "PhoneNumberAssociationsExist";
    readonly PreconditionFailed: "PreconditionFailed";
    readonly ResourceLimitExceeded: "ResourceLimitExceeded";
    readonly ServiceFailure: "ServiceFailure";
    readonly ServiceUnavailable: "ServiceUnavailable";
    readonly Throttled: "Throttled";
    readonly Throttling: "Throttling";
    readonly Unauthorized: "Unauthorized";
    readonly Unprocessable: "Unprocessable";
    readonly VoiceConnectorGroupAssociationsExist: "VoiceConnectorGroupAssociationsExist";
};
/**
 * @public
 */
export type ErrorCode = (typeof ErrorCode)[keyof typeof ErrorCode];
/**
 * <p>You don't have the permissions needed to run this action.</p>
 * @public
 */
export declare class AccessDeniedException extends __BaseException {
    readonly name: "AccessDeniedException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<AccessDeniedException, __BaseException>);
}
/**
 * <p>A validated address.</p>
 * @public
 */
export interface Address {
    /**
     * <p>The address street, such as <code>8th Avenue</code>.</p>
     * @public
     */
    streetName?: string;
    /**
     * <p>The address suffix, such as the <code>N</code> in <code>8th Avenue N</code>.</p>
     * @public
     */
    streetSuffix?: string;
    /**
     * <p>An address suffix location, such as the <code>S. Unit A</code> in
     *          <code>Central Park S. Unit A</code>.</p>
     * @public
     */
    postDirectional?: string;
    /**
     * <p>An address prefix location, such as the <code>N</code> in <code>N. Third St.</code>
     *          </p>
     * @public
     */
    preDirectional?: string;
    /**
     * <p>The numeric portion of an address.</p>
     * @public
     */
    streetNumber?: string;
    /**
     * <p>The city of an address.</p>
     * @public
     */
    city?: string;
    /**
     * <p>The state of an address.</p>
     * @public
     */
    state?: string;
    /**
     * <p>The postal code of an address.</p>
     * @public
     */
    postalCode?: string;
    /**
     * <p>The zip + 4 or postal code + 4 of an address.</p>
     * @public
     */
    postalCodePlus4?: string;
    /**
     * <p>The country of an address.</p>
     * @public
     */
    country?: string;
}
/**
 * @public
 * @enum
 */
export declare const AlexaSkillStatus: {
    readonly ACTIVE: "ACTIVE";
    readonly INACTIVE: "INACTIVE";
};
/**
 * @public
 */
export type AlexaSkillStatus = (typeof AlexaSkillStatus)[keyof typeof AlexaSkillStatus];
/**
 * @public
 */
export interface AssociatePhoneNumbersWithVoiceConnectorRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>List of phone numbers, in E.164 format.</p>
     * @public
     */
    E164PhoneNumbers: string[] | undefined;
    /**
     * <p>If true, associates the provided phone numbers with the provided Amazon Chime SDK Voice Connector and removes any previously existing associations. If false, does not associate any phone numbers that have previously existing associations.</p>
     * @public
     */
    ForceAssociate?: boolean;
}
/**
 * <p>If a phone number action fails for one or more of the phone numbers in a request,
 *          a list of the failed phone numbers is returned, along with error codes and error messages.</p>
 * @public
 */
export interface PhoneNumberError {
    /**
     * <p>The phone number ID for which the action failed.</p>
     * @public
     */
    PhoneNumberId?: string;
    /**
     * <p>The error code.</p>
     * @public
     */
    ErrorCode?: ErrorCode;
    /**
     * <p>The error message.</p>
     * @public
     */
    ErrorMessage?: string;
}
/**
 * @public
 */
export interface AssociatePhoneNumbersWithVoiceConnectorResponse {
    /**
     * <p>If the action fails for one or more of the phone numbers in the request, a list of the phone numbers is returned, along with error codes and
     *          error messages.</p>
     * @public
     */
    PhoneNumberErrors?: PhoneNumberError[];
}
/**
 * <p>The input parameters don't match the service's restrictions.</p>
 * @public
 */
export declare class BadRequestException extends __BaseException {
    readonly name: "BadRequestException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<BadRequestException, __BaseException>);
}
/**
 * <p>The client is permanently forbidden from making the request.</p>
 * @public
 */
export declare class ForbiddenException extends __BaseException {
    readonly name: "ForbiddenException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ForbiddenException, __BaseException>);
}
/**
 * <p>The requested resource couldn't be found.</p>
 * @public
 */
export declare class NotFoundException extends __BaseException {
    readonly name: "NotFoundException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<NotFoundException, __BaseException>);
}
/**
 * <p>The service encountered an unexpected error.</p>
 * @public
 */
export declare class ServiceFailureException extends __BaseException {
    readonly name: "ServiceFailureException";
    readonly $fault: "server";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceFailureException, __BaseException>);
}
/**
 * <p>The service is currently unavailable.</p>
 * @public
 */
export declare class ServiceUnavailableException extends __BaseException {
    readonly name: "ServiceUnavailableException";
    readonly $fault: "server";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ServiceUnavailableException, __BaseException>);
}
/**
 * <p>The number of customer requests exceeds the request rate limit.</p>
 * @public
 */
export declare class ThrottledClientException extends __BaseException {
    readonly name: "ThrottledClientException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ThrottledClientException, __BaseException>);
}
/**
 * <p>The client isn't authorized to request a resource.</p>
 * @public
 */
export declare class UnauthorizedClientException extends __BaseException {
    readonly name: "UnauthorizedClientException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<UnauthorizedClientException, __BaseException>);
}
/**
 * @public
 */
export interface AssociatePhoneNumbersWithVoiceConnectorGroupRequest {
    /**
     * <p>The Amazon Chime SDK Voice Connector group ID.</p>
     * @public
     */
    VoiceConnectorGroupId: string | undefined;
    /**
     * <p>List of phone numbers, in E.164 format.</p>
     * @public
     */
    E164PhoneNumbers: string[] | undefined;
    /**
     * <p>If true, associates the provided phone numbers with the provided Amazon Chime SDK Voice Connector Group and removes any previously existing associations.
     *          If false, does not associate any phone numbers that have previously existing associations.</p>
     * @public
     */
    ForceAssociate?: boolean;
}
/**
 * @public
 */
export interface AssociatePhoneNumbersWithVoiceConnectorGroupResponse {
    /**
     * <p>If the action fails for one or more of the phone numbers in the request, a list of the phone numbers is returned, along with error codes and error messages.</p>
     * @public
     */
    PhoneNumberErrors?: PhoneNumberError[];
}
/**
 * @public
 */
export interface BatchDeletePhoneNumberRequest {
    /**
     * <p>List of phone number IDs.</p>
     * @public
     */
    PhoneNumberIds: string[] | undefined;
}
/**
 * @public
 */
export interface BatchDeletePhoneNumberResponse {
    /**
     * <p>If the action fails for one or more of the phone numbers in the request, a list of the phone numbers is returned, along with error codes and error messages.</p>
     * @public
     */
    PhoneNumberErrors?: PhoneNumberError[];
}
/**
 * @public
 * @enum
 */
export declare const PhoneNumberProductType: {
    readonly SipMediaApplicationDialIn: "SipMediaApplicationDialIn";
    readonly VoiceConnector: "VoiceConnector";
};
/**
 * @public
 */
export type PhoneNumberProductType = (typeof PhoneNumberProductType)[keyof typeof PhoneNumberProductType];
/**
 * <p>The phone number ID, product type, or calling name fields to update,
 *          used with the <a>BatchUpdatePhoneNumber</a> and <a>UpdatePhoneNumber</a> actions.</p>
 * @public
 */
export interface UpdatePhoneNumberRequestItem {
    /**
     * <p>The phone number ID to update.</p>
     * @public
     */
    PhoneNumberId: string | undefined;
    /**
     * <p>The product type to update.</p>
     * @public
     */
    ProductType?: PhoneNumberProductType;
    /**
     * <p>The outbound calling name to update.</p>
     * @public
     */
    CallingName?: string;
    /**
     * <p>The name of the phone number.</p>
     * @public
     */
    Name?: string;
}
/**
 * @public
 */
export interface BatchUpdatePhoneNumberRequest {
    /**
     * <p>Lists the phone numbers in the update request.</p>
     * @public
     */
    UpdatePhoneNumberRequestItems: UpdatePhoneNumberRequestItem[] | undefined;
}
/**
 * @public
 */
export interface BatchUpdatePhoneNumberResponse {
    /**
     * <p>A list of failed phone numbers and their error messages.</p>
     * @public
     */
    PhoneNumberErrors?: PhoneNumberError[];
}
/**
 * <p>The details of an Amazon Chime SDK Voice Connector call.</p>
 * @public
 */
export interface CallDetails {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId?: string;
    /**
     * <p>The transaction ID of a Voice Connector call.</p>
     * @public
     */
    TransactionId?: string;
    /**
     * <p>Identifies a person as the caller or the callee.</p>
     * @public
     */
    IsCaller?: boolean;
}
/**
 * @public
 * @enum
 */
export declare const CallingNameStatus: {
    readonly Unassigned: "Unassigned";
    readonly UpdateFailed: "UpdateFailed";
    readonly UpdateInProgress: "UpdateInProgress";
    readonly UpdateSucceeded: "UpdateSucceeded";
};
/**
 * @public
 */
export type CallingNameStatus = (typeof CallingNameStatus)[keyof typeof CallingNameStatus];
/**
 * @public
 * @enum
 */
export declare const CallLegType: {
    readonly CALLEE: "Callee";
    readonly CALLER: "Caller";
};
/**
 * @public
 */
export type CallLegType = (typeof CallLegType)[keyof typeof CallLegType];
/**
 * <p>A suggested address.</p>
 * @public
 */
export interface CandidateAddress {
    /**
     * <p>The street information of the candidate address.</p>
     * @public
     */
    streetInfo?: string;
    /**
     * <p>The numeric portion of the candidate address.</p>
     * @public
     */
    streetNumber?: string;
    /**
     * <p>The city of the candidate address.</p>
     * @public
     */
    city?: string;
    /**
     * <p>The state of the candidate address.</p>
     * @public
     */
    state?: string;
    /**
     * <p>The postal code of the candidate address.</p>
     * @public
     */
    postalCode?: string;
    /**
     * <p>The zip + 4 or postal code +4 of the candidate address.</p>
     * @public
     */
    postalCodePlus4?: string;
    /**
     * <p>The country of the candidate address.</p>
     * @public
     */
    country?: string;
}
/**
 * @public
 * @enum
 */
export declare const Capability: {
    readonly SMS: "SMS";
    readonly Voice: "Voice";
};
/**
 * @public
 */
export type Capability = (typeof Capability)[keyof typeof Capability];
/**
 * @public
 */
export interface CreatePhoneNumberOrderRequest {
    /**
     * <p>The phone number product type.</p>
     * @public
     */
    ProductType: PhoneNumberProductType | undefined;
    /**
     * <p>List of phone numbers, in E.164 format.</p>
     * @public
     */
    E164PhoneNumbers: string[] | undefined;
    /**
     * <p>Specifies the name assigned to one or more phone numbers.</p>
     * @public
     */
    Name?: string;
}
/**
 * @public
 * @enum
 */
export declare const OrderedPhoneNumberStatus: {
    readonly Acquired: "Acquired";
    readonly Failed: "Failed";
    readonly Processing: "Processing";
};
/**
 * @public
 */
export type OrderedPhoneNumberStatus = (typeof OrderedPhoneNumberStatus)[keyof typeof OrderedPhoneNumberStatus];
/**
 * <p>A phone number for which an order has been placed.</p>
 * @public
 */
export interface OrderedPhoneNumber {
    /**
     * <p>The phone number, in E.164 format.</p>
     * @public
     */
    E164PhoneNumber?: string;
    /**
     * <p>The phone number status.</p>
     * @public
     */
    Status?: OrderedPhoneNumberStatus;
}
/**
 * @public
 * @enum
 */
export declare const PhoneNumberOrderType: {
    readonly New: "New";
    readonly Porting: "Porting";
};
/**
 * @public
 */
export type PhoneNumberOrderType = (typeof PhoneNumberOrderType)[keyof typeof PhoneNumberOrderType];
/**
 * @public
 * @enum
 */
export declare const PhoneNumberOrderStatus: {
    readonly CancelRequested: "CancelRequested";
    readonly Cancelled: "Cancelled";
    readonly ChangeRequested: "ChangeRequested";
    readonly Exception: "Exception";
    readonly FOC: "FOC";
    readonly Failed: "Failed";
    readonly Partial: "Partial";
    readonly PendingDocuments: "PendingDocuments";
    readonly Processing: "Processing";
    readonly Submitted: "Submitted";
    readonly Successful: "Successful";
};
/**
 * @public
 */
export type PhoneNumberOrderStatus = (typeof PhoneNumberOrderStatus)[keyof typeof PhoneNumberOrderStatus];
/**
 * <p>The details of an Amazon Chime SDK phone number order.</p>
 * @public
 */
export interface PhoneNumberOrder {
    /**
     * <p>The ID of the phone order.</p>
     * @public
     */
    PhoneNumberOrderId?: string;
    /**
     * <p>The phone number order product type.</p>
     * @public
     */
    ProductType?: PhoneNumberProductType;
    /**
     * <p>The status of the phone number order.</p>
     * @public
     */
    Status?: PhoneNumberOrderStatus;
    /**
     * <p>The type of phone number being ordered, local or toll-free.</p>
     * @public
     */
    OrderType?: PhoneNumberOrderType;
    /**
     * <p>The ordered phone number details, such as the phone number in E.164 format
     *          and the phone number status.</p>
     * @public
     */
    OrderedPhoneNumbers?: OrderedPhoneNumber[];
    /**
     * <p>The phone number order creation time stamp, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The updated phone number order time stamp, in ISO 8601 format.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
}
/**
 * @public
 */
export interface CreatePhoneNumberOrderResponse {
    /**
     * <p>The phone number order details.</p>
     * @public
     */
    PhoneNumberOrder?: PhoneNumberOrder;
}
/**
 * <p>The request exceeds the resource limit.</p>
 * @public
 */
export declare class ResourceLimitExceededException extends __BaseException {
    readonly name: "ResourceLimitExceededException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ResourceLimitExceededException, __BaseException>);
}
/**
 * @public
 * @enum
 */
export declare const GeoMatchLevel: {
    readonly AreaCode: "AreaCode";
    readonly Country: "Country";
};
/**
 * @public
 */
export type GeoMatchLevel = (typeof GeoMatchLevel)[keyof typeof GeoMatchLevel];
/**
 * <p>The country and area code for a proxy phone number in a proxy phone session.</p>
 * @public
 */
export interface GeoMatchParams {
    /**
     * <p>The country.</p>
     * @public
     */
    Country: string | undefined;
    /**
     * <p>The area code.</p>
     * @public
     */
    AreaCode: string | undefined;
}
/**
 * @public
 * @enum
 */
export declare const NumberSelectionBehavior: {
    readonly AvoidSticky: "AvoidSticky";
    readonly PreferSticky: "PreferSticky";
};
/**
 * @public
 */
export type NumberSelectionBehavior = (typeof NumberSelectionBehavior)[keyof typeof NumberSelectionBehavior];
/**
 * @public
 */
export interface CreateProxySessionRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The participant phone numbers.</p>
     * @public
     */
    ParticipantPhoneNumbers: string[] | undefined;
    /**
     * <p>The name of the proxy session.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The number of minutes allowed for the proxy session.</p>
     * @public
     */
    ExpiryMinutes?: number;
    /**
     * <p>The proxy session's capabilities.</p>
     * @public
     */
    Capabilities: Capability[] | undefined;
    /**
     * <p>The preference for proxy phone number reuse, or stickiness, between the same
     *             participants across sessions.</p>
     * @public
     */
    NumberSelectionBehavior?: NumberSelectionBehavior;
    /**
     * <p>The preference for matching the country or area code of the proxy phone number with that of the first participant.</p>
     * @public
     */
    GeoMatchLevel?: GeoMatchLevel;
    /**
     * <p>The country and area code for the proxy phone number.</p>
     * @public
     */
    GeoMatchParams?: GeoMatchParams;
}
/**
 * <p>The phone number and proxy phone number for a participant in an Amazon Chime SDK Voice Connector proxy session.</p>
 * @public
 */
export interface Participant {
    /**
     * <p>The participant's phone number.</p>
     * @public
     */
    PhoneNumber?: string;
    /**
     * <p>The participant's proxy phone number.</p>
     * @public
     */
    ProxyPhoneNumber?: string;
}
/**
 * @public
 * @enum
 */
export declare const ProxySessionStatus: {
    readonly Closed: "Closed";
    readonly InProgress: "InProgress";
    readonly Open: "Open";
};
/**
 * @public
 */
export type ProxySessionStatus = (typeof ProxySessionStatus)[keyof typeof ProxySessionStatus];
/**
 * <p>The proxy session for an Amazon Chime SDK Voice Connector.</p>
 * @public
 */
export interface ProxySession {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId?: string;
    /**
     * <p>The proxy session ID.</p>
     * @public
     */
    ProxySessionId?: string;
    /**
     * <p>The proxy session name.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The proxy session status.</p>
     * @public
     */
    Status?: ProxySessionStatus;
    /**
     * <p>The number of minutes allowed for the proxy session.</p>
     * @public
     */
    ExpiryMinutes?: number;
    /**
     * <p>The proxy session capabilities.</p>
     * @public
     */
    Capabilities?: Capability[];
    /**
     * <p>The created time stamp, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The updated time stamp, in ISO 8601 format.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The ended time stamp, in ISO 8601 format.</p>
     * @public
     */
    EndedTimestamp?: Date;
    /**
     * <p>The proxy session participants.</p>
     * @public
     */
    Participants?: Participant[];
    /**
     * <p>The preference for proxy phone number reuse, or stickiness, between the same participants across sessions.</p>
     * @public
     */
    NumberSelectionBehavior?: NumberSelectionBehavior;
    /**
     * <p>The preference for matching the country or area code of the proxy phone number with that of the first participant.</p>
     * @public
     */
    GeoMatchLevel?: GeoMatchLevel;
    /**
     * <p>The country and area code for the proxy phone number.</p>
     * @public
     */
    GeoMatchParams?: GeoMatchParams;
}
/**
 * @public
 */
export interface CreateProxySessionResponse {
    /**
     * <p>The proxy session details.</p>
     * @public
     */
    ProxySession?: ProxySession;
}
/**
 * <p>Multiple instances of the same request were made simultaneously.</p>
 * @public
 */
export declare class ConflictException extends __BaseException {
    readonly name: "ConflictException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<ConflictException, __BaseException>);
}
/**
 * <p>The endpoint assigned to a SIP media application.</p>
 * @public
 */
export interface SipMediaApplicationEndpoint {
    /**
     * <p>Valid Amazon Resource Name (ARN) of the Lambda function, version, or alias.
     *          The function must be created in the same AWS Region as the SIP media application.</p>
     * @public
     */
    LambdaArn?: string;
}
/**
 * <p>Describes a tag applied to a resource.</p>
 * @public
 */
export interface Tag {
    /**
     * <p>The tag's key.</p>
     * @public
     */
    Key: string | undefined;
    /**
     * <p>The tag's value.</p>
     * @public
     */
    Value: string | undefined;
}
/**
 * @public
 */
export interface CreateSipMediaApplicationRequest {
    /**
     * <p>The AWS Region assigned to the SIP media application.</p>
     * @public
     */
    AwsRegion: string | undefined;
    /**
     * <p>The SIP media application's name.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>List of endpoints (Lambda ARNs) specified for the SIP media application.</p>
     * @public
     */
    Endpoints: SipMediaApplicationEndpoint[] | undefined;
    /**
     * <p>The tags assigned to the SIP media application.</p>
     * @public
     */
    Tags?: Tag[];
}
/**
 * <p>The details of the SIP media application, including name and endpoints.
 *          An AWS account can have multiple SIP media applications.</p>
 * @public
 */
export interface SipMediaApplication {
    /**
     * <p>A SIP media application's ID.</p>
     * @public
     */
    SipMediaApplicationId?: string;
    /**
     * <p>The AWS Region in which the SIP media application is created.</p>
     * @public
     */
    AwsRegion?: string;
    /**
     * <p>The SIP media application's name.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>List of endpoints for a SIP media application. Currently, only one endpoint per
     *          SIP media application is permitted.</p>
     * @public
     */
    Endpoints?: SipMediaApplicationEndpoint[];
    /**
     * <p>The SIP media application creation timestamp, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which the SIP media application was updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The ARN of the SIP media application.</p>
     * @public
     */
    SipMediaApplicationArn?: string;
}
/**
 * @public
 */
export interface CreateSipMediaApplicationResponse {
    /**
     * <p>The SIP media application details.</p>
     * @public
     */
    SipMediaApplication?: SipMediaApplication;
}
/**
 * @public
 */
export interface CreateSipMediaApplicationCallRequest {
    /**
     * <p>The phone number that a user calls from. This is a phone number in your
     *          Amazon Chime SDK phone number inventory.</p>
     * @public
     */
    FromPhoneNumber: string | undefined;
    /**
     * <p>The phone number that the service should call.</p>
     * @public
     */
    ToPhoneNumber: string | undefined;
    /**
     * <p>The ID of the SIP media application.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
    /**
     * <p>The SIP headers added to an outbound call leg.</p>
     * @public
     */
    SipHeaders?: Record<string, string>;
    /**
     * <p>Context passed to a CreateSipMediaApplication API call. For example, you could pass
     *             key-value pairs such as: <code>"FirstName": "John", "LastName": "Doe"</code>
     *          </p>
     * @public
     */
    ArgumentsMap?: Record<string, string>;
}
/**
 * <p>A <code>Call</code> instance for a SIP media application.</p>
 * @public
 */
export interface SipMediaApplicationCall {
    /**
     * <p>The call's transaction ID.</p>
     * @public
     */
    TransactionId?: string;
}
/**
 * @public
 */
export interface CreateSipMediaApplicationCallResponse {
    /**
     * <p>The actual call.</p>
     * @public
     */
    SipMediaApplicationCall?: SipMediaApplicationCall;
}
/**
 * <p>A target SIP media application and other details, such as priority and AWS Region,
 *          to be specified in the SIP rule. Only one SIP rule per AWS Region can be provided.</p>
 * @public
 */
export interface SipRuleTargetApplication {
    /**
     * <p>The ID of a rule's target SIP media application.</p>
     * @public
     */
    SipMediaApplicationId?: string;
    /**
     * <p>The priority setting of a rule's target SIP media application.</p>
     * @public
     */
    Priority?: number;
    /**
     * <p>The AWS Region of a rule's target SIP media application.</p>
     * @public
     */
    AwsRegion?: string;
}
/**
 * @public
 * @enum
 */
export declare const SipRuleTriggerType: {
    readonly RequestUriHostname: "RequestUriHostname";
    readonly ToPhoneNumber: "ToPhoneNumber";
};
/**
 * @public
 */
export type SipRuleTriggerType = (typeof SipRuleTriggerType)[keyof typeof SipRuleTriggerType];
/**
 * @public
 */
export interface CreateSipRuleRequest {
    /**
     * <p>The name of the SIP rule.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>The type of trigger assigned to the SIP rule in <code>TriggerValue</code>,
     *          currently <code>RequestUriHostname</code> or <code>ToPhoneNumber</code>.</p>
     * @public
     */
    TriggerType: SipRuleTriggerType | undefined;
    /**
     * <p>If <code>TriggerType</code> is <code>RequestUriHostname</code>, the
     *          value can be the outbound host name of a Voice Connector. If
     *          <code>TriggerType</code> is <code>ToPhoneNumber</code>, the value can
     *          be a customer-owned phone number in the E164 format. The
     *          <code>SipMediaApplication</code> specified in the <code>SipRule</code> is triggered
     *          if the request URI in an incoming SIP request matches the
     *          <code>RequestUriHostname</code>, or if the <code>To</code> header in the
     *          incoming SIP request matches the <code>ToPhoneNumber</code> value.</p>
     * @public
     */
    TriggerValue: string | undefined;
    /**
     * <p>Disables or enables a SIP rule. You must disable SIP rules
     *          before you can delete them.</p>
     * @public
     */
    Disabled?: boolean;
    /**
     * <p>List of SIP media applications, with priority and AWS Region. Only one SIP
     *          application per AWS Region can be used.</p>
     * @public
     */
    TargetApplications?: SipRuleTargetApplication[];
}
/**
 * <p>The details of a SIP rule, including name, triggers, and target applications.
 *          An AWS account can have multiple SIP rules.</p>
 * @public
 */
export interface SipRule {
    /**
     * <p>A SIP rule's ID.</p>
     * @public
     */
    SipRuleId?: string;
    /**
     * <p>A SIP rule's name.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>Indicates whether the SIP rule is enabled or disabled. You must disable a rule before you can delete it.</p>
     * @public
     */
    Disabled?: boolean;
    /**
     * <p>The type of trigger set for a SIP rule, either a phone number or a URI request host name.</p>
     * @public
     */
    TriggerType?: SipRuleTriggerType;
    /**
     * <p>The value set for a SIP rule's trigger type. Either a phone number or a URI hostname.</p>
     * @public
     */
    TriggerValue?: string;
    /**
     * <p>The target SIP media application and other details, such as priority and AWS Region,
     *          to be specified in the SIP rule. Only one SIP rule per AWS Region can be provided.</p>
     * @public
     */
    TargetApplications?: SipRuleTargetApplication[];
    /**
     * <p>The time at which the SIP rule was created, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which the SIP rule was updated, in ISO 8601 format.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
}
/**
 * @public
 */
export interface CreateSipRuleResponse {
    /**
     * <p>The SIP rule information, including the rule ID, triggers, and target applications.</p>
     * @public
     */
    SipRule?: SipRule;
}
/**
 * @public
 * @enum
 */
export declare const VoiceConnectorAwsRegion: {
    readonly AP_NORTHEAST_1: "ap-northeast-1";
    readonly AP_NORTHEAST_2: "ap-northeast-2";
    readonly AP_SOUTHEAST_1: "ap-southeast-1";
    readonly AP_SOUTHEAST_2: "ap-southeast-2";
    readonly CA_CENTRAL_1: "ca-central-1";
    readonly EU_CENTRAL_1: "eu-central-1";
    readonly EU_WEST_1: "eu-west-1";
    readonly EU_WEST_2: "eu-west-2";
    readonly US_EAST_1: "us-east-1";
    readonly US_WEST_2: "us-west-2";
};
/**
 * @public
 */
export type VoiceConnectorAwsRegion = (typeof VoiceConnectorAwsRegion)[keyof typeof VoiceConnectorAwsRegion];
/**
 * @public
 */
export interface CreateVoiceConnectorRequest {
    /**
     * <p>The name of the Voice Connector.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>The AWS Region in which the Amazon Chime SDK Voice Connector is created. Default value:
     *          <code>us-east-1</code> .</p>
     * @public
     */
    AwsRegion?: VoiceConnectorAwsRegion;
    /**
     * <p>Enables or disables encryption for the Voice Connector.</p>
     * @public
     */
    RequireEncryption: boolean | undefined;
    /**
     * <p>The tags assigned to the Voice Connector.</p>
     * @public
     */
    Tags?: Tag[];
}
/**
 * <p>The Amazon Chime SDK Voice Connector configuration, including outbound
 *          host name and encryption settings.</p>
 * @public
 */
export interface VoiceConnector {
    /**
     * <p>The Voice Connector's ID.</p>
     * @public
     */
    VoiceConnectorId?: string;
    /**
     * <p>The AWS Region in which the Voice Connector is created.
     *          Default: us-east-1.</p>
     * @public
     */
    AwsRegion?: VoiceConnectorAwsRegion;
    /**
     * <p>The Voice Connector's name.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The outbound host name for the Voice Connector.</p>
     * @public
     */
    OutboundHostName?: string;
    /**
     * <p>Enables or disables encryption for the Voice Connector.</p>
     * @public
     */
    RequireEncryption?: boolean;
    /**
     * <p>The Voice Connector's creation timestamp, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The Voice Connector's updated timestamp, in ISO 8601 format.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The ARN of the Voice Connector.</p>
     * @public
     */
    VoiceConnectorArn?: string;
}
/**
 * @public
 */
export interface CreateVoiceConnectorResponse {
    /**
     * <p>The details of the Voice Connector.</p>
     * @public
     */
    VoiceConnector?: VoiceConnector;
}
/**
 * <p>For Amazon Chime SDK Voice Connector groups, the Amazon Chime SDK Voice
 *          Connectors to which you route inbound calls. Includes priority configuration
 *          settings. Limit: 3 VoiceConnectorItems per Voice Connector group.</p>
 * @public
 */
export interface VoiceConnectorItem {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The priority setting of a Voice Connector item. Calls are routed to hosts
     *            in priority order, with 1 as the highest priority. When hosts have equal priority,
     *            the system distributes calls among them based on their relative weight.</p>
     * @public
     */
    Priority: number | undefined;
}
/**
 * @public
 */
export interface CreateVoiceConnectorGroupRequest {
    /**
     * <p>The name of the Voice Connector group.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>Lists the Voice Connectors that inbound calls are routed to.</p>
     * @public
     */
    VoiceConnectorItems?: VoiceConnectorItem[];
}
/**
 * <p>The Amazon Chime SDK Voice Connector group configuration, including
 *          associated Voice Connectors. You can include Voice Connectors from different
 *          AWS Regions in a group. This creates a fault tolerant mechanism for
 *          fallback in case of availability events.</p>
 * @public
 */
export interface VoiceConnectorGroup {
    /**
     * <p>The ID of a Voice Connector group.</p>
     * @public
     */
    VoiceConnectorGroupId?: string;
    /**
     * <p>The name of a Voice Connector group.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The Voice Connectors to which you route inbound calls.</p>
     * @public
     */
    VoiceConnectorItems?: VoiceConnectorItem[];
    /**
     * <p>The Voice Connector group's creation time stamp, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The Voice Connector group's creation time stamp, in ISO 8601 format.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The ARN of the Voice Connector group.</p>
     * @public
     */
    VoiceConnectorGroupArn?: string;
}
/**
 * @public
 */
export interface CreateVoiceConnectorGroupResponse {
    /**
     * <p>The details of the Voice Connector group.</p>
     * @public
     */
    VoiceConnectorGroup?: VoiceConnectorGroup;
}
/**
 * @public
 */
export interface CreateVoiceProfileRequest {
    /**
     * <p>The ID of the speaker search task.</p>
     * @public
     */
    SpeakerSearchTaskId: string | undefined;
}
/**
 * <p>The combination of a voice print and caller ID.</p>
 * @public
 */
export interface VoiceProfile {
    /**
     * <p>The ID of the voice profile.</p>
     * @public
     */
    VoiceProfileId?: string;
    /**
     * <p>The ARN of the voice profile.</p>
     * @public
     */
    VoiceProfileArn?: string;
    /**
     * <p>The ID of the domain that contains the voice profile.</p>
     * @public
     */
    VoiceProfileDomainId?: string;
    /**
     * <p>The time at which the voice profile was created and enrolled.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which the voice profile was last updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The time at which a voice profile expires unless you re-enroll the caller via the
     *          <code>UpdateVoiceProfile</code> API.</p>
     * @public
     */
    ExpirationTimestamp?: Date;
}
/**
 * @public
 */
export interface CreateVoiceProfileResponse {
    /**
     * <p>The requested voice profile.</p>
     * @public
     */
    VoiceProfile?: VoiceProfile;
}
/**
 * <p>Access to the target resource is no longer available at the origin server. This condition is likely to be permanent.</p>
 * @public
 */
export declare class GoneException extends __BaseException {
    readonly name: "GoneException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<GoneException, __BaseException>);
}
/**
 * <p>A structure that contains the configuration settings for server-side encryption.</p>
 *          <note>
 *             <p>We only support symmetric keys. Do not use asymmetric or HMAC keys, or KMS aliases.</p>
 *          </note>
 * @public
 */
export interface ServerSideEncryptionConfiguration {
    /**
     * <p>The ARN of the KMS key used to encrypt the enrollment data in a voice profile domain.
     *          Asymmetric customer managed keys are not supported.</p>
     * @public
     */
    KmsKeyArn: string | undefined;
}
/**
 * @public
 */
export interface CreateVoiceProfileDomainRequest {
    /**
     * <p>The name of the voice profile domain.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>A description of the voice profile domain.</p>
     * @public
     */
    Description?: string;
    /**
     * <p>The server-side encryption configuration for the request.</p>
     * @public
     */
    ServerSideEncryptionConfiguration: ServerSideEncryptionConfiguration | undefined;
    /**
     * <p>The unique identifier for the client request. Use a different token for different domain creation requests.</p>
     * @public
     */
    ClientRequestToken?: string;
    /**
     * <p>The tags assigned to the domain.</p>
     * @public
     */
    Tags?: Tag[];
}
/**
 * <p>A collection of voice profiles.</p>
 * @public
 */
export interface VoiceProfileDomain {
    /**
     * <p>The ID of the voice profile domain.</p>
     * @public
     */
    VoiceProfileDomainId?: string;
    /**
     * <p>The voice profile domain's Amazon Resource Number (ARN).</p>
     * @public
     */
    VoiceProfileDomainArn?: string;
    /**
     * <p>The name of the voice profile domain.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The description of the voice profile domain.</p>
     * @public
     */
    Description?: string;
    /**
     * <p>A structure that contains the configuration settings for server-side encryption.</p>
     * @public
     */
    ServerSideEncryptionConfiguration?: ServerSideEncryptionConfiguration;
    /**
     * <p>The time at which the voice profile domain was created.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which the voice profile was last updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
}
/**
 * @public
 */
export interface CreateVoiceProfileDomainResponse {
    /**
     * <p>The requested voice profile domain.</p>
     * @public
     */
    VoiceProfileDomain?: VoiceProfileDomain;
}
/**
 * @public
 */
export interface DeletePhoneNumberRequest {
    /**
     * <p>The phone number ID.</p>
     * @public
     */
    PhoneNumberId: string | undefined;
}
/**
 * @public
 */
export interface DeleteProxySessionRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The proxy session ID.</p>
     * @public
     */
    ProxySessionId: string | undefined;
}
/**
 * @public
 */
export interface DeleteSipMediaApplicationRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
}
/**
 * @public
 */
export interface DeleteSipRuleRequest {
    /**
     * <p>The SIP rule ID.</p>
     * @public
     */
    SipRuleId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorEmergencyCallingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorGroupRequest {
    /**
     * <p>The Voice Connector Group ID.</p>
     * @public
     */
    VoiceConnectorGroupId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorOriginationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorProxyRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorStreamingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorTerminationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceConnectorTerminationCredentialsRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The RFC2617 compliant username associated with the SIP credentials,
     *          in US-ASCII format.</p>
     * @public
     */
    Usernames: string[] | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceProfileRequest {
    /**
     * <p>The voice profile ID.</p>
     * @public
     */
    VoiceProfileId: string | undefined;
}
/**
 * @public
 */
export interface DeleteVoiceProfileDomainRequest {
    /**
     * <p>The voice profile domain ID.</p>
     * @public
     */
    VoiceProfileDomainId: string | undefined;
}
/**
 * @public
 */
export interface DisassociatePhoneNumbersFromVoiceConnectorRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>List of phone numbers, in E.164 format.</p>
     * @public
     */
    E164PhoneNumbers: string[] | undefined;
}
/**
 * @public
 */
export interface DisassociatePhoneNumbersFromVoiceConnectorResponse {
    /**
     * <p>If the action fails for one or more of the phone numbers in the request, a
     *          list of the phone numbers is returned, along with error codes and error messages.</p>
     * @public
     */
    PhoneNumberErrors?: PhoneNumberError[];
}
/**
 * @public
 */
export interface DisassociatePhoneNumbersFromVoiceConnectorGroupRequest {
    /**
     * <p>The Voice Connector group ID.</p>
     * @public
     */
    VoiceConnectorGroupId: string | undefined;
    /**
     * <p>The list of phone numbers, in E.164 format.</p>
     * @public
     */
    E164PhoneNumbers: string[] | undefined;
}
/**
 * @public
 */
export interface DisassociatePhoneNumbersFromVoiceConnectorGroupResponse {
    /**
     * <p>If the action fails for one or more of the phone numbers in the request,
     *          a list of the phone numbers is returned, along with error codes and error messages.</p>
     * @public
     */
    PhoneNumberErrors?: PhoneNumberError[];
}
/**
 * <p>The Amazon Chime SDK Voice Connector settings. Includes any Amazon
 *          S3 buckets designated for storing call detail records.</p>
 * @public
 */
export interface VoiceConnectorSettings {
    /**
     * <p>The S3 bucket that stores the Voice Connector's call detail records.</p>
     * @public
     */
    CdrBucket?: string;
}
/**
 * @public
 */
export interface GetGlobalSettingsResponse {
    /**
     * <p>The Voice Connector settings.</p>
     * @public
     */
    VoiceConnector?: VoiceConnectorSettings;
}
/**
 * @public
 */
export interface GetPhoneNumberRequest {
    /**
     * <p>The phone number ID.</p>
     * @public
     */
    PhoneNumberId: string | undefined;
}
/**
 * @public
 * @enum
 */
export declare const PhoneNumberAssociationName: {
    readonly SipRuleId: "SipRuleId";
    readonly VoiceConnectorGroupId: "VoiceConnectorGroupId";
    readonly VoiceConnectorId: "VoiceConnectorId";
};
/**
 * @public
 */
export type PhoneNumberAssociationName = (typeof PhoneNumberAssociationName)[keyof typeof PhoneNumberAssociationName];
/**
 * <p>The phone number associations, such as an Amazon Chime SDK account ID, user ID,
 *          Voice Connector ID, or Voice Connector group ID.</p>
 * @public
 */
export interface PhoneNumberAssociation {
    /**
     * <p>Contains the ID for the entity specified in Name.</p>
     * @public
     */
    Value?: string;
    /**
     * <p>Defines the association with an Amazon Chime SDK account ID, user ID, Voice Connector ID, or Voice Connector group ID.</p>
     * @public
     */
    Name?: PhoneNumberAssociationName;
    /**
     * <p>The timestamp of the phone number association, in ISO 8601 format.</p>
     * @public
     */
    AssociatedTimestamp?: Date;
}
/**
 * <p>The phone number capabilities for Amazon Chime SDK phone numbers,
 *          such as enabled inbound and outbound calling, and text messaging.</p>
 * @public
 */
export interface PhoneNumberCapabilities {
    /**
     * <p>Allows or denies inbound calling for the specified phone number.</p>
     * @public
     */
    InboundCall?: boolean;
    /**
     * <p>Allows or denies outbound calling for the specified phone number.</p>
     * @public
     */
    OutboundCall?: boolean;
    /**
     * <p>Allows or denies inbound SMS messaging for the specified phone number.</p>
     * @public
     */
    InboundSMS?: boolean;
    /**
     * <p>Allows or denies outbound SMS messaging for the specified phone number.</p>
     * @public
     */
    OutboundSMS?: boolean;
    /**
     * <p>Allows or denies inbound MMS messaging for the specified phone number.</p>
     * @public
     */
    InboundMMS?: boolean;
    /**
     * <p>Allows or denies inbound MMS messaging for the specified phone number.</p>
     * @public
     */
    OutboundMMS?: boolean;
}
/**
 * @public
 * @enum
 */
export declare const PhoneNumberStatus: {
    readonly AcquireFailed: "AcquireFailed";
    readonly AcquireInProgress: "AcquireInProgress";
    readonly Assigned: "Assigned";
    readonly Cancelled: "Cancelled";
    readonly DeleteFailed: "DeleteFailed";
    readonly DeleteInProgress: "DeleteInProgress";
    readonly PortinCancelRequested: "PortinCancelRequested";
    readonly PortinInProgress: "PortinInProgress";
    readonly ReleaseFailed: "ReleaseFailed";
    readonly ReleaseInProgress: "ReleaseInProgress";
    readonly Unassigned: "Unassigned";
};
/**
 * @public
 */
export type PhoneNumberStatus = (typeof PhoneNumberStatus)[keyof typeof PhoneNumberStatus];
/**
 * @public
 * @enum
 */
export declare const PhoneNumberType: {
    readonly Local: "Local";
    readonly TollFree: "TollFree";
};
/**
 * @public
 */
export type PhoneNumberType = (typeof PhoneNumberType)[keyof typeof PhoneNumberType];
/**
 * <p>A phone number used to call an Amazon
 *          Chime SDK Voice Connector.</p>
 * @public
 */
export interface PhoneNumber {
    /**
     * <p>The phone number's ID.</p>
     * @public
     */
    PhoneNumberId?: string;
    /**
     * <p>The phone number, in E.164 format.</p>
     * @public
     */
    E164PhoneNumber?: string;
    /**
     * <p>The phone number's country. Format: ISO 3166-1 alpha-2.</p>
     * @public
     */
    Country?: string;
    /**
     * <p>The phone number's type.</p>
     * @public
     */
    Type?: PhoneNumberType;
    /**
     * <p>The phone number's product type.</p>
     * @public
     */
    ProductType?: PhoneNumberProductType;
    /**
     * <p>The phone number's status.</p>
     * @public
     */
    Status?: PhoneNumberStatus;
    /**
     * <p>The phone number's capabilities.</p>
     * @public
     */
    Capabilities?: PhoneNumberCapabilities;
    /**
     * <p>The phone number's associations.</p>
     * @public
     */
    Associations?: PhoneNumberAssociation[];
    /**
     * <p>The outbound calling name associated with the phone number.</p>
     * @public
     */
    CallingName?: string;
    /**
     * <p>The outbound calling name status.</p>
     * @public
     */
    CallingNameStatus?: CallingNameStatus;
    /**
     * <p>The phone number creation timestamp, in ISO 8601 format.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The updated phone number timestamp, in ISO 8601 format.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The deleted phone number timestamp, in ISO 8601 format.</p>
     * @public
     */
    DeletionTimestamp?: Date;
    /**
     * <p>The phone number's order ID.</p>
     * @public
     */
    OrderId?: string;
    /**
     * <p>The name of the phone number.</p>
     * @public
     */
    Name?: string;
}
/**
 * @public
 */
export interface GetPhoneNumberResponse {
    /**
     * <p>The phone number details.</p>
     * @public
     */
    PhoneNumber?: PhoneNumber;
}
/**
 * @public
 */
export interface GetPhoneNumberOrderRequest {
    /**
     * <p>The ID of the phone number order .</p>
     * @public
     */
    PhoneNumberOrderId: string | undefined;
}
/**
 * @public
 */
export interface GetPhoneNumberOrderResponse {
    /**
     * <p>The phone number order details.</p>
     * @public
     */
    PhoneNumberOrder?: PhoneNumberOrder;
}
/**
 * @public
 */
export interface GetPhoneNumberSettingsResponse {
    /**
     * <p>The default outbound calling name for the account.</p>
     * @public
     */
    CallingName?: string;
    /**
     * <p>The updated outbound calling name timestamp, in ISO 8601 format.</p>
     * @public
     */
    CallingNameUpdatedTimestamp?: Date;
}
/**
 * @public
 */
export interface GetProxySessionRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The proxy session ID.</p>
     * @public
     */
    ProxySessionId: string | undefined;
}
/**
 * @public
 */
export interface GetProxySessionResponse {
    /**
     * <p>The proxy session details.</p>
     * @public
     */
    ProxySession?: ProxySession;
}
/**
 * @public
 */
export interface GetSipMediaApplicationRequest {
    /**
     * <p>The SIP media application ID .</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
}
/**
 * @public
 */
export interface GetSipMediaApplicationResponse {
    /**
     * <p>The details of the SIP media application.</p>
     * @public
     */
    SipMediaApplication?: SipMediaApplication;
}
/**
 * @public
 */
export interface GetSipMediaApplicationAlexaSkillConfigurationRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
}
/**
 * <p>The Alexa Skill configuration of a SIP media application.</p>
 * @public
 */
export interface SipMediaApplicationAlexaSkillConfiguration {
    /**
     * <p>The status of the Alexa Skill configuration.</p>
     * @public
     */
    AlexaSkillStatus: AlexaSkillStatus | undefined;
    /**
     * <p>The ID of the Alexa Skill configuration.</p>
     * @public
     */
    AlexaSkillIds: string[] | undefined;
}
/**
 * @public
 */
export interface GetSipMediaApplicationAlexaSkillConfigurationResponse {
    /**
     * <p>Returns the Alexa Skill configuration.</p>
     * @public
     */
    SipMediaApplicationAlexaSkillConfiguration?: SipMediaApplicationAlexaSkillConfiguration;
}
/**
 * @public
 */
export interface GetSipMediaApplicationLoggingConfigurationRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
}
/**
 * <p>The logging configuration of a SIP media application.</p>
 * @public
 */
export interface SipMediaApplicationLoggingConfiguration {
    /**
     * <p>Enables message logging for the specified SIP media application.</p>
     * @public
     */
    EnableSipMediaApplicationMessageLogs?: boolean;
}
/**
 * @public
 */
export interface GetSipMediaApplicationLoggingConfigurationResponse {
    /**
     * <p>The actual logging configuration.</p>
     * @public
     */
    SipMediaApplicationLoggingConfiguration?: SipMediaApplicationLoggingConfiguration;
}
/**
 * @public
 */
export interface GetSipRuleRequest {
    /**
     * <p>The SIP rule ID.</p>
     * @public
     */
    SipRuleId: string | undefined;
}
/**
 * @public
 */
export interface GetSipRuleResponse {
    /**
     * <p>The SIP rule details.</p>
     * @public
     */
    SipRule?: SipRule;
}
/**
 * @public
 */
export interface GetSpeakerSearchTaskRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The ID of the speaker search task.</p>
     * @public
     */
    SpeakerSearchTaskId: string | undefined;
}
/**
 * <p>The result of a speaker search analysis.</p>
 * @public
 */
export interface SpeakerSearchResult {
    /**
     * <p>The confidence score in the speaker search analysis.</p>
     * @public
     */
    ConfidenceScore?: number;
    /**
     * <p>The voice profile ID.</p>
     * @public
     */
    VoiceProfileId?: string;
}
/**
 * <p>The details of a speaker search task.</p>
 * @public
 */
export interface SpeakerSearchDetails {
    /**
     * <p>The result value in the speaker search details.</p>
     * @public
     */
    Results?: SpeakerSearchResult[];
    /**
     * <p>The status of a voice print generation operation, <code>VoiceprintGenerationSuccess</code> or <code>VoiceprintGenerationFailure</code>..</p>
     * @public
     */
    VoiceprintGenerationStatus?: string;
}
/**
 * <p>A representation of an asynchronous request to perform speaker search analysis on a
 *          Voice Connector call.</p>
 * @public
 */
export interface SpeakerSearchTask {
    /**
     * <p>The speaker search task ID.</p>
     * @public
     */
    SpeakerSearchTaskId?: string;
    /**
     * <p>The status of the speaker search task, <code>IN_QUEUE</code>, <code>IN_PROGRESS</code>, <code>PARTIAL_SUCCESS</code>, <code>SUCCEEDED</code>,
     *          <code>FAILED</code>, or <code>STOPPED</code>.</p>
     * @public
     */
    SpeakerSearchTaskStatus?: string;
    /**
     * <p>The call details of a speaker search task.</p>
     * @public
     */
    CallDetails?: CallDetails;
    /**
     * <p>The details of a speaker search task.</p>
     * @public
     */
    SpeakerSearchDetails?: SpeakerSearchDetails;
    /**
     * <p>The time at which a speaker search task was created.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which a speaker search task was updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The time at which the speaker search task began.</p>
     * @public
     */
    StartedTimestamp?: Date;
    /**
     * <p>A detailed message about the status of a speaker search.</p>
     * @public
     */
    StatusMessage?: string;
}
/**
 * @public
 */
export interface GetSpeakerSearchTaskResponse {
    /**
     * <p>The details of the speaker search task.</p>
     * @public
     */
    SpeakerSearchTask?: SpeakerSearchTask;
}
/**
 * @public
 */
export interface GetVoiceConnectorRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface GetVoiceConnectorResponse {
    /**
     * <p>The Voice Connector details.</p>
     * @public
     */
    VoiceConnector?: VoiceConnector;
}
/**
 * @public
 */
export interface GetVoiceConnectorEmergencyCallingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * <p>The Dialed Number Identification Service (DNIS) emergency calling configuration
 *          details associated with an Amazon Chime SDK Voice Connector's emergency calling
 *          configuration.</p>
 * @public
 */
export interface DNISEmergencyCallingConfiguration {
    /**
     * <p>The DNIS phone number that you route emergency calls to, in E.164 format.</p>
     * @public
     */
    EmergencyPhoneNumber: string | undefined;
    /**
     * <p>The DNIS phone number for routing test emergency calls to, in E.164 format.</p>
     * @public
     */
    TestPhoneNumber?: string;
    /**
     * <p>The country from which emergency calls are allowed, in ISO 3166-1 alpha-2 format.</p>
     * @public
     */
    CallingCountry: string | undefined;
}
/**
 * <p>The emergency calling configuration details associated with an Amazon Chime SDK
 *          Voice Connector.</p>
 * @public
 */
export interface EmergencyCallingConfiguration {
    /**
     * <p>The Dialed Number Identification Service (DNIS) emergency calling configuration
     *          details.</p>
     * @public
     */
    DNIS?: DNISEmergencyCallingConfiguration[];
}
/**
 * @public
 */
export interface GetVoiceConnectorEmergencyCallingConfigurationResponse {
    /**
     * <p>The details of the emergency calling configuration.</p>
     * @public
     */
    EmergencyCallingConfiguration?: EmergencyCallingConfiguration;
}
/**
 * @public
 */
export interface GetVoiceConnectorGroupRequest {
    /**
     * <p>The Voice Connector group ID.</p>
     * @public
     */
    VoiceConnectorGroupId: string | undefined;
}
/**
 * @public
 */
export interface GetVoiceConnectorGroupResponse {
    /**
     * <p>The details of the Voice Connector group.</p>
     * @public
     */
    VoiceConnectorGroup?: VoiceConnectorGroup;
}
/**
 * @public
 */
export interface GetVoiceConnectorLoggingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * <p>The logging configuration associated with an Amazon Chime SDK Voice Connector.
 *          Specifies whether SIP message logs can be sent to Amazon CloudWatch Logs.</p>
 * @public
 */
export interface LoggingConfiguration {
    /**
     * <p>Boolean that enables sending SIP message logs to Amazon CloudWatch.</p>
     * @public
     */
    EnableSIPLogs?: boolean;
    /**
     * <p>Enables or disables media metrics logging.</p>
     * @public
     */
    EnableMediaMetricLogs?: boolean;
}
/**
 * @public
 */
export interface GetVoiceConnectorLoggingConfigurationResponse {
    /**
     * <p>The logging configuration details .</p>
     * @public
     */
    LoggingConfiguration?: LoggingConfiguration;
}
/**
 * @public
 */
export interface GetVoiceConnectorOriginationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 * @enum
 */
export declare const OriginationRouteProtocol: {
    readonly TCP: "TCP";
    readonly UDP: "UDP";
};
/**
 * @public
 */
export type OriginationRouteProtocol = (typeof OriginationRouteProtocol)[keyof typeof OriginationRouteProtocol];
/**
 * <p>Origination routes define call distribution properties for your SIP hosts to
 *          receive inbound calls using an Amazon Chime SDK Voice Connector. Limit: Ten origination
 *          routes for each Voice Connector.</p>
 *          <note>
 *             <p>The parameters listed below are not required, but you must use at least one.</p>
 *          </note>
 * @public
 */
export interface OriginationRoute {
    /**
     * <p>The FQDN or IP address to contact for origination traffic.</p>
     * @public
     */
    Host?: string;
    /**
     * <p>The designated origination route port. Defaults to 5060.</p>
     * @public
     */
    Port?: number;
    /**
     * <p>The protocol to use for the origination route. Encryption-enabled Amazon Chime SDK Voice Connectors use
     *          TCP protocol by default.</p>
     * @public
     */
    Protocol?: OriginationRouteProtocol;
    /**
     * <p>The priority associated with the host, with 1 being the highest priority. Higher
     *          priority hosts are attempted first.</p>
     * @public
     */
    Priority?: number;
    /**
     * <p>The weight assigned to an origination route. When hosts have equal priority,
     *          calls are distributed between them based on their relative weights.</p>
     * @public
     */
    Weight?: number;
}
/**
 * <p>Origination settings enable your SIP hosts to receive inbound calls using your
 *          Amazon Chime SDK Voice Connector.</p>
 *          <note>
 *             <p>The parameters listed below are not required, but you must use at least
 *          one.</p>
 *          </note>
 * @public
 */
export interface Origination {
    /**
     * <p>The call distribution properties defined for your SIP hosts. Valid range: Minimum
     *          value of 1. Maximum value of 20. This parameter is not required, but you must specify
     *          this parameter or <code>Disabled</code>.</p>
     * @public
     */
    Routes?: OriginationRoute[];
    /**
     * <p>When origination settings are disabled, inbound calls are not enabled for your
     *          Amazon Chime SDK Voice Connector.
     *          This parameter is not required, but you must specify this parameter or
     *          <code>Routes</code>.</p>
     * @public
     */
    Disabled?: boolean;
}
/**
 * @public
 */
export interface GetVoiceConnectorOriginationResponse {
    /**
     * <p>The origination setting details.</p>
     * @public
     */
    Origination?: Origination;
}
/**
 * @public
 */
export interface GetVoiceConnectorProxyRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * <p>The proxy configuration for an Amazon Chime SDK Voice Connector.</p>
 * @public
 */
export interface Proxy {
    /**
     * <p>The default number of minutes allowed for proxy sessions.</p>
     * @public
     */
    DefaultSessionExpiryMinutes?: number;
    /**
     * <p>When true, stops proxy sessions from being created on the specified Amazon Chime SDK Voice Connector.</p>
     * @public
     */
    Disabled?: boolean;
    /**
     * <p>The phone number to route calls to after a proxy session expires.</p>
     * @public
     */
    FallBackPhoneNumber?: string;
    /**
     * <p>The countries for proxy phone numbers to be selected from.</p>
     * @public
     */
    PhoneNumberCountries?: string[];
}
/**
 * @public
 */
export interface GetVoiceConnectorProxyResponse {
    /**
     * <p>The proxy configuration details.</p>
     * @public
     */
    Proxy?: Proxy;
}
/**
 * @public
 */
export interface GetVoiceConnectorStreamingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * <p>The configuration for a call analytics task.</p>
 * @public
 */
export interface MediaInsightsConfiguration {
    /**
     * <p>Denotes the configration as enabled or disabled.</p>
     * @public
     */
    Disabled?: boolean;
    /**
     * <p>The configuration's ARN.</p>
     * @public
     */
    ConfigurationArn?: string;
}
/**
 * @public
 * @enum
 */
export declare const NotificationTarget: {
    readonly EventBridge: "EventBridge";
    readonly SNS: "SNS";
    readonly SQS: "SQS";
};
/**
 * @public
 */
export type NotificationTarget = (typeof NotificationTarget)[keyof typeof NotificationTarget];
/**
 * <p>The target recipient for a streaming configuration notification.</p>
 * @public
 */
export interface StreamingNotificationTarget {
    /**
     * <p>The streaming notification target.</p>
     * @public
     */
    NotificationTarget?: NotificationTarget;
}
/**
 * <p>The streaming configuration associated with an Amazon Chime SDK Voice Connector.
 *          Specifies whether media streaming is enabled for sending to Amazon Kinesis, and shows the retention
 *          period for the Amazon Kinesis data, in hours.</p>
 * @public
 */
export interface StreamingConfiguration {
    /**
     * <p>The amount of time, in hours, to the Kinesis data.</p>
     * @public
     */
    DataRetentionInHours: number | undefined;
    /**
     * <p>When true, streaming to Kinesis is off.</p>
     * @public
     */
    Disabled: boolean | undefined;
    /**
     * <p>The streaming notification targets.</p>
     * @public
     */
    StreamingNotificationTargets?: StreamingNotificationTarget[];
    /**
     * <p>The call analytics configuration.</p>
     * @public
     */
    MediaInsightsConfiguration?: MediaInsightsConfiguration;
}
/**
 * @public
 */
export interface GetVoiceConnectorStreamingConfigurationResponse {
    /**
     * <p>The details of the streaming configuration.</p>
     * @public
     */
    StreamingConfiguration?: StreamingConfiguration;
}
/**
 * @public
 */
export interface GetVoiceConnectorTerminationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * <p>Termination settings enable SIP hosts to make outbound calls using an Amazon Chime SDK Voice Connector.</p>
 * @public
 */
export interface Termination {
    /**
     * <p>The limit on calls per second. Max value based on account service quota. Default value of 1.</p>
     * @public
     */
    CpsLimit?: number;
    /**
     * <p>The default outbound calling number.</p>
     * @public
     */
    DefaultPhoneNumber?: string;
    /**
     * <p>The countries to which calls are allowed, in ISO 3166-1 alpha-2 format. Required.</p>
     * @public
     */
    CallingRegions?: string[];
    /**
     * <p>The IP addresses allowed to make calls, in CIDR format.</p>
     * @public
     */
    CidrAllowedList?: string[];
    /**
     * <p>When termination is disabled, outbound calls cannot be made.</p>
     * @public
     */
    Disabled?: boolean;
}
/**
 * @public
 */
export interface GetVoiceConnectorTerminationResponse {
    /**
     * <p>The termination setting details.</p>
     * @public
     */
    Termination?: Termination;
}
/**
 * @public
 */
export interface GetVoiceConnectorTerminationHealthRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * <p>The termination health details, including the source IP address and timestamp of the last successful <code>SIP OPTIONS</code> message from your SIP infrastructure.</p>
 * @public
 */
export interface TerminationHealth {
    /**
     * <p>The timestamp, in ISO 8601 format.</p>
     * @public
     */
    Timestamp?: Date;
    /**
     * <p>The source IP address.</p>
     * @public
     */
    Source?: string;
}
/**
 * @public
 */
export interface GetVoiceConnectorTerminationHealthResponse {
    /**
     * <p>The termination health details.</p>
     * @public
     */
    TerminationHealth?: TerminationHealth;
}
/**
 * @public
 */
export interface GetVoiceProfileRequest {
    /**
     * <p>The voice profile ID.</p>
     * @public
     */
    VoiceProfileId: string | undefined;
}
/**
 * @public
 */
export interface GetVoiceProfileResponse {
    /**
     * <p>The voice profile details.</p>
     * @public
     */
    VoiceProfile?: VoiceProfile;
}
/**
 * @public
 */
export interface GetVoiceProfileDomainRequest {
    /**
     * <p>The voice profile domain ID.</p>
     * @public
     */
    VoiceProfileDomainId: string | undefined;
}
/**
 * @public
 */
export interface GetVoiceProfileDomainResponse {
    /**
     * <p>The details of the voice profile domain.</p>
     * @public
     */
    VoiceProfileDomain?: VoiceProfileDomain;
}
/**
 * @public
 */
export interface GetVoiceToneAnalysisTaskRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The ID of the voice tone anlysis task.</p>
     * @public
     */
    VoiceToneAnalysisTaskId: string | undefined;
    /**
     * <p>Specifies whether the voice being analyzed is the caller (originator) or the callee (responder).</p>
     * @public
     */
    IsCaller: boolean | undefined;
}
/**
 * <p>A representation of an asynchronous request to perform voice tone analysis on a Voice Connector call.</p>
 * @public
 */
export interface VoiceToneAnalysisTask {
    /**
     * <p>The ID of the voice tone analysis task.</p>
     * @public
     */
    VoiceToneAnalysisTaskId?: string;
    /**
     * <p>The status of a voice tone analysis task, <code>IN_QUEUE</code>, <code>IN_PROGRESS</code>, <code>PARTIAL_SUCCESS</code>, <code>SUCCEEDED</code>,
     *          <code>FAILED</code>, or <code>STOPPED</code>.</p>
     * @public
     */
    VoiceToneAnalysisTaskStatus?: string;
    /**
     * <p>The call details of a voice tone analysis task.</p>
     * @public
     */
    CallDetails?: CallDetails;
    /**
     * <p>The time at which a voice tone analysis task was created.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which a voice tone analysis task was updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>The time at which a voice tone analysis task started.</p>
     * @public
     */
    StartedTimestamp?: Date;
    /**
     * <p>The status of a voice tone analysis task.</p>
     * @public
     */
    StatusMessage?: string;
}
/**
 * @public
 */
export interface GetVoiceToneAnalysisTaskResponse {
    /**
     * <p>The details of the voice tone analysis task.</p>
     * @public
     */
    VoiceToneAnalysisTask?: VoiceToneAnalysisTask;
}
/**
 * @public
 */
export interface ListAvailableVoiceConnectorRegionsResponse {
    /**
     * <p>The list of AWS Regions.</p>
     * @public
     */
    VoiceConnectorRegions?: VoiceConnectorAwsRegion[];
}
/**
 * @public
 */
export interface ListPhoneNumberOrdersRequest {
    /**
     * <p>The token used to retrieve the next page of results.</p>
     * @public
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return in a single call.</p>
     * @public
     */
    MaxResults?: number;
}
/**
 * @public
 */
export interface ListPhoneNumberOrdersResponse {
    /**
     * <p>The phone number order details.</p>
     * @public
     */
    PhoneNumberOrders?: PhoneNumberOrder[];
    /**
     * <p>The token used to retrieve the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListPhoneNumbersRequest {
    /**
     * <p>The status of your organization's phone numbers.</p>
     * @public
     */
    Status?: string;
    /**
     * <p>The phone number product types.</p>
     * @public
     */
    ProductType?: PhoneNumberProductType;
    /**
     * <p>The filter to limit the number of results.</p>
     * @public
     */
    FilterName?: PhoneNumberAssociationName;
    /**
     * <p>The filter value.</p>
     * @public
     */
    FilterValue?: string;
    /**
     * <p>The maximum number of results to return in a single call.</p>
     * @public
     */
    MaxResults?: number;
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListPhoneNumbersResponse {
    /**
     * <p>The phone number details.</p>
     * @public
     */
    PhoneNumbers?: PhoneNumber[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListProxySessionsRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The proxy session status.</p>
     * @public
     */
    Status?: ProxySessionStatus;
    /**
     * <p>The token used to retrieve the next page of results.</p>
     * @public
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return in a single call.</p>
     * @public
     */
    MaxResults?: number;
}
/**
 * @public
 */
export interface ListProxySessionsResponse {
    /**
     * <p>The proxy sessions' details.</p>
     * @public
     */
    ProxySessions?: ProxySession[];
    /**
     * <p>The token used to retrieve the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListSipMediaApplicationsRequest {
    /**
     * <p>The maximum number of results to return in a single call. Defaults to 100.</p>
     * @public
     */
    MaxResults?: number;
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListSipMediaApplicationsResponse {
    /**
     * <p>The list of SIP media applications and application details.</p>
     * @public
     */
    SipMediaApplications?: SipMediaApplication[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListSipRulesRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId?: string;
    /**
     * <p>The maximum number of results to return in a single call. Defaults to 100.</p>
     * @public
     */
    MaxResults?: number;
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListSipRulesResponse {
    /**
     * <p>The list of SIP rules and details.</p>
     * @public
     */
    SipRules?: SipRule[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListSupportedPhoneNumberCountriesRequest {
    /**
     * <p>The phone number product type.</p>
     * @public
     */
    ProductType: PhoneNumberProductType | undefined;
}
/**
 * <p>The phone number's country.</p>
 * @public
 */
export interface PhoneNumberCountry {
    /**
     * <p>The phone number country code. Format: ISO 3166-1 alpha-2.</p>
     * @public
     */
    CountryCode?: string;
    /**
     * <p>The supported phone number types.</p>
     * @public
     */
    SupportedPhoneNumberTypes?: PhoneNumberType[];
}
/**
 * @public
 */
export interface ListSupportedPhoneNumberCountriesResponse {
    /**
     * <p>The supported phone number countries.</p>
     * @public
     */
    PhoneNumberCountries?: PhoneNumberCountry[];
}
/**
 * @public
 */
export interface ListTagsForResourceRequest {
    /**
     * <p>The resource ARN.</p>
     * @public
     */
    ResourceARN: string | undefined;
}
/**
 * @public
 */
export interface ListTagsForResourceResponse {
    /**
     * <p>The tags in the list.</p>
     * @public
     */
    Tags?: Tag[];
}
/**
 * @public
 */
export interface ListVoiceConnectorGroupsRequest {
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return in a single call.  </p>
     * @public
     */
    MaxResults?: number;
}
/**
 * @public
 */
export interface ListVoiceConnectorGroupsResponse {
    /**
     * <p>The details of the Voice Connector groups.</p>
     * @public
     */
    VoiceConnectorGroups?: VoiceConnectorGroup[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListVoiceConnectorsRequest {
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return in a single call.</p>
     * @public
     */
    MaxResults?: number;
}
/**
 * @public
 */
export interface ListVoiceConnectorsResponse {
    /**
     * <p>The details of the Voice Connectors.</p>
     * @public
     */
    VoiceConnectors?: VoiceConnector[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListVoiceConnectorTerminationCredentialsRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
}
/**
 * @public
 */
export interface ListVoiceConnectorTerminationCredentialsResponse {
    /**
     * <p>A list of user names.</p>
     * @public
     */
    Usernames?: string[];
}
/**
 * @public
 */
export interface ListVoiceProfileDomainsRequest {
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results to return in a single call.</p>
     * @public
     */
    MaxResults?: number;
}
/**
 * <p>A high-level overview of a voice profile domain.</p>
 * @public
 */
export interface VoiceProfileDomainSummary {
    /**
     * <p>The ID of the voice profile domain summary.</p>
     * @public
     */
    VoiceProfileDomainId?: string;
    /**
     * <p>The ARN of a voice profile in a voice profile domain summary.</p>
     * @public
     */
    VoiceProfileDomainArn?: string;
    /**
     * <p>The name of the voice profile domain summary.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>Describes the voice profile domain summary.</p>
     * @public
     */
    Description?: string;
    /**
     * <p>The time at which the voice profile domain summary was created.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which the voice profile domain summary was last updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
}
/**
 * @public
 */
export interface ListVoiceProfileDomainsResponse {
    /**
     * <p>The list of voice profile domains.</p>
     * @public
     */
    VoiceProfileDomains?: VoiceProfileDomainSummary[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface ListVoiceProfilesRequest {
    /**
     * <p>The ID of the voice profile domain.</p>
     * @public
     */
    VoiceProfileDomainId: string | undefined;
    /**
     * <p>The token used to retrieve the next page of results.</p>
     * @public
     */
    NextToken?: string;
    /**
     * <p>The maximum number of results in the request.</p>
     * @public
     */
    MaxResults?: number;
}
/**
 * <p>A high-level summary of a voice profile.</p>
 * @public
 */
export interface VoiceProfileSummary {
    /**
     * <p>The ID of the voice profile in a voice profile summary.</p>
     * @public
     */
    VoiceProfileId?: string;
    /**
     * <p>The ARN of the voice profile in a voice profile summary.</p>
     * @public
     */
    VoiceProfileArn?: string;
    /**
     * <p>The ID of the voice profile domain in a voice profile summary.</p>
     * @public
     */
    VoiceProfileDomainId?: string;
    /**
     * <p>The time at which a voice profile summary was created.</p>
     * @public
     */
    CreatedTimestamp?: Date;
    /**
     * <p>The time at which a voice profile summary was last updated.</p>
     * @public
     */
    UpdatedTimestamp?: Date;
    /**
     * <p>Extends the life of the voice profile. You can use <code>UpdateVoiceProfile</code> to refresh an existing voice profile's voice print and extend the life of the summary.</p>
     * @public
     */
    ExpirationTimestamp?: Date;
}
/**
 * @public
 */
export interface ListVoiceProfilesResponse {
    /**
     * <p>The list of voice profiles.</p>
     * @public
     */
    VoiceProfiles?: VoiceProfileSummary[];
    /**
     * <p>The token used to retrieve the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface PutSipMediaApplicationAlexaSkillConfigurationRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
    /**
     * <p>The Alexa Skill configuration.</p>
     * @public
     */
    SipMediaApplicationAlexaSkillConfiguration?: SipMediaApplicationAlexaSkillConfiguration;
}
/**
 * @public
 */
export interface PutSipMediaApplicationAlexaSkillConfigurationResponse {
    /**
     * <p>Returns the Alexa Skill configuration.</p>
     * @public
     */
    SipMediaApplicationAlexaSkillConfiguration?: SipMediaApplicationAlexaSkillConfiguration;
}
/**
 * @public
 */
export interface PutSipMediaApplicationLoggingConfigurationRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
    /**
     * <p>The logging configuration for the specified SIP media application.</p>
     * @public
     */
    SipMediaApplicationLoggingConfiguration?: SipMediaApplicationLoggingConfiguration;
}
/**
 * @public
 */
export interface PutSipMediaApplicationLoggingConfigurationResponse {
    /**
     * <p>The updated logging configuration for the specified SIP media application.</p>
     * @public
     */
    SipMediaApplicationLoggingConfiguration?: SipMediaApplicationLoggingConfiguration;
}
/**
 * @public
 */
export interface PutVoiceConnectorEmergencyCallingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The configuration being updated.</p>
     * @public
     */
    EmergencyCallingConfiguration: EmergencyCallingConfiguration | undefined;
}
/**
 * @public
 */
export interface PutVoiceConnectorEmergencyCallingConfigurationResponse {
    /**
     * <p>The updated configuration.</p>
     * @public
     */
    EmergencyCallingConfiguration?: EmergencyCallingConfiguration;
}
/**
 * @public
 */
export interface PutVoiceConnectorLoggingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The logging configuration being updated.</p>
     * @public
     */
    LoggingConfiguration: LoggingConfiguration | undefined;
}
/**
 * @public
 */
export interface PutVoiceConnectorLoggingConfigurationResponse {
    /**
     * <p>The updated logging configuration.</p>
     * @public
     */
    LoggingConfiguration?: LoggingConfiguration;
}
/**
 * @public
 */
export interface PutVoiceConnectorOriginationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The origination settings being updated.</p>
     * @public
     */
    Origination: Origination | undefined;
}
/**
 * @public
 */
export interface PutVoiceConnectorOriginationResponse {
    /**
     * <p>The updated origination settings.</p>
     * @public
     */
    Origination?: Origination;
}
/**
 * @public
 */
export interface PutVoiceConnectorProxyRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The default number of minutes allowed for proxy session.</p>
     * @public
     */
    DefaultSessionExpiryMinutes: number | undefined;
    /**
     * <p>The countries for proxy phone numbers to be selected from.</p>
     * @public
     */
    PhoneNumberPoolCountries: string[] | undefined;
    /**
     * <p>The phone number to route calls to after a proxy session expires.</p>
     * @public
     */
    FallBackPhoneNumber?: string;
    /**
     * <p>When true, stops proxy sessions from being created on the specified Amazon Chime SDK Voice Connector.</p>
     * @public
     */
    Disabled?: boolean;
}
/**
 * @public
 */
export interface PutVoiceConnectorProxyResponse {
    /**
     * <p>The proxy configuration details.</p>
     * @public
     */
    Proxy?: Proxy;
}
/**
 * @public
 */
export interface PutVoiceConnectorStreamingConfigurationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The streaming settings being updated.</p>
     * @public
     */
    StreamingConfiguration: StreamingConfiguration | undefined;
}
/**
 * @public
 */
export interface PutVoiceConnectorStreamingConfigurationResponse {
    /**
     * <p>The updated streaming settings.</p>
     * @public
     */
    StreamingConfiguration?: StreamingConfiguration;
}
/**
 * @public
 */
export interface PutVoiceConnectorTerminationRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The termination settings to be updated.</p>
     * @public
     */
    Termination: Termination | undefined;
}
/**
 * @public
 */
export interface PutVoiceConnectorTerminationResponse {
    /**
     * <p>The updated termination settings.</p>
     * @public
     */
    Termination?: Termination;
}
/**
 * <p>The SIP credentials used to authenticate requests to an Amazon Chime SDK Voice Connector.</p>
 * @public
 */
export interface Credential {
    /**
     * <p>The RFC2617 compliant user name associated with the SIP credentials, in
     *          US-ASCII format.</p>
     * @public
     */
    Username?: string;
    /**
     * <p>The RFC2617 compliant password associated with the SIP credentials, in US-ASCII format.</p>
     * @public
     */
    Password?: string;
}
/**
 * @public
 */
export interface PutVoiceConnectorTerminationCredentialsRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The termination credentials being updated.</p>
     * @public
     */
    Credentials?: Credential[];
}
/**
 * @public
 */
export interface RestorePhoneNumberRequest {
    /**
     * <p>The ID of the phone number being restored.</p>
     * @public
     */
    PhoneNumberId: string | undefined;
}
/**
 * @public
 */
export interface RestorePhoneNumberResponse {
    /**
     * <p>The restored phone number.</p>
     * @public
     */
    PhoneNumber?: PhoneNumber;
}
/**
 * @public
 */
export interface SearchAvailablePhoneNumbersRequest {
    /**
     * <p>Confines a search to just the phone numbers associated with the specified area code.</p>
     * @public
     */
    AreaCode?: string;
    /**
     * <p>Confines a search to just the phone numbers associated with the specified city.</p>
     * @public
     */
    City?: string;
    /**
     * <p>Confines a search to just the phone numbers associated with the specified country.</p>
     * @public
     */
    Country?: string;
    /**
     * <p>Confines a search to just the phone numbers associated with the specified state.</p>
     * @public
     */
    State?: string;
    /**
     * <p>Confines a search to just the phone numbers associated with the specified toll-free prefix.</p>
     * @public
     */
    TollFreePrefix?: string;
    /**
     * <p>Confines a search to just the phone numbers associated with the specified phone number type, either <b>local</b> or <b>toll-free</b>.</p>
     * @public
     */
    PhoneNumberType?: PhoneNumberType;
    /**
     * <p>The maximum number of results to return.</p>
     * @public
     */
    MaxResults?: number;
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface SearchAvailablePhoneNumbersResponse {
    /**
     * <p>Confines a search to just the phone numbers in the E.164 format.</p>
     * @public
     */
    E164PhoneNumbers?: string[];
    /**
     * <p>The token used to return the next page of results.</p>
     * @public
     */
    NextToken?: string;
}
/**
 * @public
 */
export interface StartSpeakerSearchTaskRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The transaction ID of the call being analyzed.</p>
     * @public
     */
    TransactionId: string | undefined;
    /**
     * <p>The ID of the voice profile domain that will store the voice profile.</p>
     * @public
     */
    VoiceProfileDomainId: string | undefined;
    /**
     * <p>The unique identifier for the client request. Use a different token for different speaker search tasks.</p>
     * @public
     */
    ClientRequestToken?: string;
    /**
     * <p>Specifies which call leg to stream for speaker search.</p>
     * @public
     */
    CallLeg?: CallLegType;
}
/**
 * @public
 */
export interface StartSpeakerSearchTaskResponse {
    /**
     * <p>The details of the speaker search task.</p>
     * @public
     */
    SpeakerSearchTask?: SpeakerSearchTask;
}
/**
 * <p>A well-formed request couldn't be followed due to semantic errors.</p>
 * @public
 */
export declare class UnprocessableEntityException extends __BaseException {
    readonly name: "UnprocessableEntityException";
    readonly $fault: "client";
    Code?: ErrorCode;
    Message?: string;
    /**
     * @internal
     */
    constructor(opts: __ExceptionOptionType<UnprocessableEntityException, __BaseException>);
}
/**
 * @public
 * @enum
 */
export declare const LanguageCode: {
    readonly EN_US: "en-US";
};
/**
 * @public
 */
export type LanguageCode = (typeof LanguageCode)[keyof typeof LanguageCode];
/**
 * @public
 */
export interface StartVoiceToneAnalysisTaskRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The transaction ID.</p>
     * @public
     */
    TransactionId: string | undefined;
    /**
     * <p>The language code.</p>
     * @public
     */
    LanguageCode: LanguageCode | undefined;
    /**
     * <p>The unique identifier for the client request. Use a different token for different voice tone analysis
     *          tasks.</p>
     * @public
     */
    ClientRequestToken?: string;
}
/**
 * @public
 */
export interface StartVoiceToneAnalysisTaskResponse {
    /**
     * <p>The details of the voice tone analysis task.</p>
     * @public
     */
    VoiceToneAnalysisTask?: VoiceToneAnalysisTask;
}
/**
 * @public
 */
export interface StopSpeakerSearchTaskRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The speaker search task ID.</p>
     * @public
     */
    SpeakerSearchTaskId: string | undefined;
}
/**
 * @public
 */
export interface StopVoiceToneAnalysisTaskRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The ID of the voice tone analysis task.</p>
     * @public
     */
    VoiceToneAnalysisTaskId: string | undefined;
}
/**
 * @public
 */
export interface TagResourceRequest {
    /**
     * <p>The ARN of the resource being tagged. </p>
     * @public
     */
    ResourceARN: string | undefined;
    /**
     * <p>A list of the tags being added to the resource.</p>
     * @public
     */
    Tags: Tag[] | undefined;
}
/**
 * @public
 */
export interface UntagResourceRequest {
    /**
     * <p>The ARN of the resource having its tags removed.</p>
     * @public
     */
    ResourceARN: string | undefined;
    /**
     * <p>The keys of the tags being removed from the resource.</p>
     * @public
     */
    TagKeys: string[] | undefined;
}
/**
 * @public
 */
export interface UpdateGlobalSettingsRequest {
    /**
     * <p>The Voice Connector settings.</p>
     * @public
     */
    VoiceConnector?: VoiceConnectorSettings;
}
/**
 * @public
 */
export interface UpdatePhoneNumberRequest {
    /**
     * <p>The phone number ID.</p>
     * @public
     */
    PhoneNumberId: string | undefined;
    /**
     * <p>The product type.</p>
     * @public
     */
    ProductType?: PhoneNumberProductType;
    /**
     * <p>The outbound calling name associated with the phone number.</p>
     * @public
     */
    CallingName?: string;
    /**
     * <p>Specifies the name assigned to one or more phone numbers.</p>
     * @public
     */
    Name?: string;
}
/**
 * @public
 */
export interface UpdatePhoneNumberResponse {
    /**
     * <p>The updated phone number details.</p>
     * @public
     */
    PhoneNumber?: PhoneNumber;
}
/**
 * @public
 */
export interface UpdatePhoneNumberSettingsRequest {
    /**
     * <p>The default outbound calling name for the account.</p>
     * @public
     */
    CallingName: string | undefined;
}
/**
 * @public
 */
export interface UpdateProxySessionRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The proxy session ID.</p>
     * @public
     */
    ProxySessionId: string | undefined;
    /**
     * <p>The proxy session capabilities.</p>
     * @public
     */
    Capabilities: Capability[] | undefined;
    /**
     * <p>The number of minutes allowed for the proxy session.</p>
     * @public
     */
    ExpiryMinutes?: number;
}
/**
 * @public
 */
export interface UpdateProxySessionResponse {
    /**
     * <p>The updated proxy session details.</p>
     * @public
     */
    ProxySession?: ProxySession;
}
/**
 * @public
 */
export interface UpdateSipMediaApplicationRequest {
    /**
     * <p>The SIP media application ID.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
    /**
     * <p>The new name for the specified SIP media application.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The new set of endpoints for the specified SIP media application.</p>
     * @public
     */
    Endpoints?: SipMediaApplicationEndpoint[];
}
/**
 * @public
 */
export interface UpdateSipMediaApplicationResponse {
    /**
     * <p>The updated SIP media application’s details.</p>
     * @public
     */
    SipMediaApplication?: SipMediaApplication;
}
/**
 * @public
 */
export interface UpdateSipMediaApplicationCallRequest {
    /**
     * <p>The ID of the SIP media application handling the call.</p>
     * @public
     */
    SipMediaApplicationId: string | undefined;
    /**
     * <p>The ID of the call transaction.</p>
     * @public
     */
    TransactionId: string | undefined;
    /**
     * <p>Arguments made available to the Lambda function as part of the
     *          <code>CALL_UPDATE_REQUESTED</code> event. Can contain 0-20 key-value pairs.</p>
     * @public
     */
    Arguments: Record<string, string> | undefined;
}
/**
 * @public
 */
export interface UpdateSipMediaApplicationCallResponse {
    /**
     * <p>A <code>Call</code> instance for a SIP media application.</p>
     * @public
     */
    SipMediaApplicationCall?: SipMediaApplicationCall;
}
/**
 * @public
 */
export interface UpdateSipRuleRequest {
    /**
     * <p>The SIP rule ID.</p>
     * @public
     */
    SipRuleId: string | undefined;
    /**
     * <p>The new name for the specified SIP rule.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>The new value that indicates whether the rule is disabled.</p>
     * @public
     */
    Disabled?: boolean;
    /**
     * <p>The new list of target applications.</p>
     * @public
     */
    TargetApplications?: SipRuleTargetApplication[];
}
/**
 * @public
 */
export interface UpdateSipRuleResponse {
    /**
     * <p>The updated SIP rule details.</p>
     * @public
     */
    SipRule?: SipRule;
}
/**
 * @public
 */
export interface UpdateVoiceConnectorRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorId: string | undefined;
    /**
     * <p>The name of the Voice Connector.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>When enabled, requires encryption for the Voice Connector.</p>
     * @public
     */
    RequireEncryption: boolean | undefined;
}
/**
 * @public
 */
export interface UpdateVoiceConnectorResponse {
    /**
     * <p>The updated Voice Connector details.</p>
     * @public
     */
    VoiceConnector?: VoiceConnector;
}
/**
 * @public
 */
export interface UpdateVoiceConnectorGroupRequest {
    /**
     * <p>The Voice Connector ID.</p>
     * @public
     */
    VoiceConnectorGroupId: string | undefined;
    /**
     * <p>The name of the Voice Connector group.</p>
     * @public
     */
    Name: string | undefined;
    /**
     * <p>The <code>VoiceConnectorItems</code> to associate with the Voice Connector
     *          group.</p>
     * @public
     */
    VoiceConnectorItems: VoiceConnectorItem[] | undefined;
}
/**
 * @public
 */
export interface UpdateVoiceConnectorGroupResponse {
    /**
     * <p>The updated Voice Connector group.</p>
     * @public
     */
    VoiceConnectorGroup?: VoiceConnectorGroup;
}
/**
 * @public
 */
export interface UpdateVoiceProfileRequest {
    /**
     * <p>The profile ID.</p>
     * @public
     */
    VoiceProfileId: string | undefined;
    /**
     * <p>The ID of the speaker search task.</p>
     * @public
     */
    SpeakerSearchTaskId: string | undefined;
}
/**
 * @public
 */
export interface UpdateVoiceProfileResponse {
    /**
     * <p>The updated voice profile settings.</p>
     * @public
     */
    VoiceProfile?: VoiceProfile;
}
/**
 * @public
 */
export interface UpdateVoiceProfileDomainRequest {
    /**
     * <p>The domain ID.</p>
     * @public
     */
    VoiceProfileDomainId: string | undefined;
    /**
     * <p>The name of the voice profile domain.</p>
     * @public
     */
    Name?: string;
    /**
     * <p>The description of the voice profile domain.</p>
     * @public
     */
    Description?: string;
}
/**
 * @public
 */
export interface UpdateVoiceProfileDomainResponse {
    /**
     * <p>The updated details of the voice profile domain.</p>
     * @public
     */
    VoiceProfileDomain?: VoiceProfileDomain;
}
/**
 * @public
 */
export interface ValidateE911AddressRequest {
    /**
     * <p>The AWS account ID.</p>
     * @public
     */
    AwsAccountId: string | undefined;
    /**
     * <p>The address street number, such as <code>200</code> or <code>2121</code>.</p>
     * @public
     */
    StreetNumber: string | undefined;
    /**
     * <p>The address street information, such as <code>8th Avenue</code>.</p>
     * @public
     */
    StreetInfo: string | undefined;
    /**
     * <p>The address city, such as <code>Portland</code>.</p>
     * @public
     */
    City: string | undefined;
    /**
     * <p>The address state, such as <code>ME</code>.</p>
     * @public
     */
    State: string | undefined;
    /**
     * <p>The country in the address being validated.</p>
     * @public
     */
    Country: string | undefined;
    /**
     * <p>The dress postal code, such <code>04352</code>.</p>
     * @public
     */
    PostalCode: string | undefined;
}
/**
 * @public
 */
export interface ValidateE911AddressResponse {
    /**
     * <p>Number indicating the result of address validation. <code>0</code> means the
     *          address was perfect as-is and successfully validated. <code>1</code> means the
     *          address was corrected. <code>2</code> means the address sent was not close
     *          enough and was not validated.</p>
     * @public
     */
    ValidationResult?: number;
    /**
     * <p>The ID that represents the address.</p>
     * @public
     */
    AddressExternalId?: string;
    /**
     * <p>The validated address.</p>
     * @public
     */
    Address?: Address;
    /**
     * <p>The list of address suggestions..</p>
     * @public
     */
    CandidateAddressList?: CandidateAddress[];
}
/**
 * @internal
 */
export declare const AddressFilterSensitiveLog: (obj: Address) => any;
/**
 * @internal
 */
export declare const AssociatePhoneNumbersWithVoiceConnectorRequestFilterSensitiveLog: (obj: AssociatePhoneNumbersWithVoiceConnectorRequest) => any;
/**
 * @internal
 */
export declare const PhoneNumberErrorFilterSensitiveLog: (obj: PhoneNumberError) => any;
/**
 * @internal
 */
export declare const AssociatePhoneNumbersWithVoiceConnectorResponseFilterSensitiveLog: (obj: AssociatePhoneNumbersWithVoiceConnectorResponse) => any;
/**
 * @internal
 */
export declare const AssociatePhoneNumbersWithVoiceConnectorGroupRequestFilterSensitiveLog: (obj: AssociatePhoneNumbersWithVoiceConnectorGroupRequest) => any;
/**
 * @internal
 */
export declare const AssociatePhoneNumbersWithVoiceConnectorGroupResponseFilterSensitiveLog: (obj: AssociatePhoneNumbersWithVoiceConnectorGroupResponse) => any;
/**
 * @internal
 */
export declare const BatchDeletePhoneNumberResponseFilterSensitiveLog: (obj: BatchDeletePhoneNumberResponse) => any;
/**
 * @internal
 */
export declare const UpdatePhoneNumberRequestItemFilterSensitiveLog: (obj: UpdatePhoneNumberRequestItem) => any;
/**
 * @internal
 */
export declare const BatchUpdatePhoneNumberRequestFilterSensitiveLog: (obj: BatchUpdatePhoneNumberRequest) => any;
/**
 * @internal
 */
export declare const BatchUpdatePhoneNumberResponseFilterSensitiveLog: (obj: BatchUpdatePhoneNumberResponse) => any;
/**
 * @internal
 */
export declare const CandidateAddressFilterSensitiveLog: (obj: CandidateAddress) => any;
/**
 * @internal
 */
export declare const CreatePhoneNumberOrderRequestFilterSensitiveLog: (obj: CreatePhoneNumberOrderRequest) => any;
/**
 * @internal
 */
export declare const OrderedPhoneNumberFilterSensitiveLog: (obj: OrderedPhoneNumber) => any;
/**
 * @internal
 */
export declare const PhoneNumberOrderFilterSensitiveLog: (obj: PhoneNumberOrder) => any;
/**
 * @internal
 */
export declare const CreatePhoneNumberOrderResponseFilterSensitiveLog: (obj: CreatePhoneNumberOrderResponse) => any;
/**
 * @internal
 */
export declare const CreateProxySessionRequestFilterSensitiveLog: (obj: CreateProxySessionRequest) => any;
/**
 * @internal
 */
export declare const ParticipantFilterSensitiveLog: (obj: Participant) => any;
/**
 * @internal
 */
export declare const ProxySessionFilterSensitiveLog: (obj: ProxySession) => any;
/**
 * @internal
 */
export declare const CreateProxySessionResponseFilterSensitiveLog: (obj: CreateProxySessionResponse) => any;
/**
 * @internal
 */
export declare const SipMediaApplicationEndpointFilterSensitiveLog: (obj: SipMediaApplicationEndpoint) => any;
/**
 * @internal
 */
export declare const TagFilterSensitiveLog: (obj: Tag) => any;
/**
 * @internal
 */
export declare const CreateSipMediaApplicationRequestFilterSensitiveLog: (obj: CreateSipMediaApplicationRequest) => any;
/**
 * @internal
 */
export declare const SipMediaApplicationFilterSensitiveLog: (obj: SipMediaApplication) => any;
/**
 * @internal
 */
export declare const CreateSipMediaApplicationResponseFilterSensitiveLog: (obj: CreateSipMediaApplicationResponse) => any;
/**
 * @internal
 */
export declare const CreateSipMediaApplicationCallRequestFilterSensitiveLog: (obj: CreateSipMediaApplicationCallRequest) => any;
/**
 * @internal
 */
export declare const CreateVoiceConnectorRequestFilterSensitiveLog: (obj: CreateVoiceConnectorRequest) => any;
/**
 * @internal
 */
export declare const VoiceProfileFilterSensitiveLog: (obj: VoiceProfile) => any;
/**
 * @internal
 */
export declare const CreateVoiceProfileResponseFilterSensitiveLog: (obj: CreateVoiceProfileResponse) => any;
/**
 * @internal
 */
export declare const ServerSideEncryptionConfigurationFilterSensitiveLog: (obj: ServerSideEncryptionConfiguration) => any;
/**
 * @internal
 */
export declare const CreateVoiceProfileDomainRequestFilterSensitiveLog: (obj: CreateVoiceProfileDomainRequest) => any;
/**
 * @internal
 */
export declare const VoiceProfileDomainFilterSensitiveLog: (obj: VoiceProfileDomain) => any;
/**
 * @internal
 */
export declare const CreateVoiceProfileDomainResponseFilterSensitiveLog: (obj: CreateVoiceProfileDomainResponse) => any;
/**
 * @internal
 */
export declare const DeletePhoneNumberRequestFilterSensitiveLog: (obj: DeletePhoneNumberRequest) => any;
/**
 * @internal
 */
export declare const DeleteVoiceConnectorTerminationCredentialsRequestFilterSensitiveLog: (obj: DeleteVoiceConnectorTerminationCredentialsRequest) => any;
/**
 * @internal
 */
export declare const DisassociatePhoneNumbersFromVoiceConnectorRequestFilterSensitiveLog: (obj: DisassociatePhoneNumbersFromVoiceConnectorRequest) => any;
/**
 * @internal
 */
export declare const DisassociatePhoneNumbersFromVoiceConnectorResponseFilterSensitiveLog: (obj: DisassociatePhoneNumbersFromVoiceConnectorResponse) => any;
/**
 * @internal
 */
export declare const DisassociatePhoneNumbersFromVoiceConnectorGroupRequestFilterSensitiveLog: (obj: DisassociatePhoneNumbersFromVoiceConnectorGroupRequest) => any;
/**
 * @internal
 */
export declare const DisassociatePhoneNumbersFromVoiceConnectorGroupResponseFilterSensitiveLog: (obj: DisassociatePhoneNumbersFromVoiceConnectorGroupResponse) => any;
/**
 * @internal
 */
export declare const GetPhoneNumberRequestFilterSensitiveLog: (obj: GetPhoneNumberRequest) => any;
/**
 * @internal
 */
export declare const PhoneNumberFilterSensitiveLog: (obj: PhoneNumber) => any;
/**
 * @internal
 */
export declare const GetPhoneNumberResponseFilterSensitiveLog: (obj: GetPhoneNumberResponse) => any;
/**
 * @internal
 */
export declare const GetPhoneNumberOrderResponseFilterSensitiveLog: (obj: GetPhoneNumberOrderResponse) => any;
/**
 * @internal
 */
export declare const GetPhoneNumberSettingsResponseFilterSensitiveLog: (obj: GetPhoneNumberSettingsResponse) => any;
/**
 * @internal
 */
export declare const GetProxySessionResponseFilterSensitiveLog: (obj: GetProxySessionResponse) => any;
/**
 * @internal
 */
export declare const GetSipMediaApplicationResponseFilterSensitiveLog: (obj: GetSipMediaApplicationResponse) => any;
/**
 * @internal
 */
export declare const SipMediaApplicationAlexaSkillConfigurationFilterSensitiveLog: (obj: SipMediaApplicationAlexaSkillConfiguration) => any;
/**
 * @internal
 */
export declare const GetSipMediaApplicationAlexaSkillConfigurationResponseFilterSensitiveLog: (obj: GetSipMediaApplicationAlexaSkillConfigurationResponse) => any;
/**
 * @internal
 */
export declare const DNISEmergencyCallingConfigurationFilterSensitiveLog: (obj: DNISEmergencyCallingConfiguration) => any;
/**
 * @internal
 */
export declare const EmergencyCallingConfigurationFilterSensitiveLog: (obj: EmergencyCallingConfiguration) => any;
/**
 * @internal
 */
export declare const GetVoiceConnectorEmergencyCallingConfigurationResponseFilterSensitiveLog: (obj: GetVoiceConnectorEmergencyCallingConfigurationResponse) => any;
/**
 * @internal
 */
export declare const ProxyFilterSensitiveLog: (obj: Proxy) => any;
/**
 * @internal
 */
export declare const GetVoiceConnectorProxyResponseFilterSensitiveLog: (obj: GetVoiceConnectorProxyResponse) => any;
/**
 * @internal
 */
export declare const MediaInsightsConfigurationFilterSensitiveLog: (obj: MediaInsightsConfiguration) => any;
/**
 * @internal
 */
export declare const StreamingConfigurationFilterSensitiveLog: (obj: StreamingConfiguration) => any;
/**
 * @internal
 */
export declare const GetVoiceConnectorStreamingConfigurationResponseFilterSensitiveLog: (obj: GetVoiceConnectorStreamingConfigurationResponse) => any;
/**
 * @internal
 */
export declare const TerminationFilterSensitiveLog: (obj: Termination) => any;
/**
 * @internal
 */
export declare const GetVoiceConnectorTerminationResponseFilterSensitiveLog: (obj: GetVoiceConnectorTerminationResponse) => any;
/**
 * @internal
 */
export declare const GetVoiceProfileResponseFilterSensitiveLog: (obj: GetVoiceProfileResponse) => any;
/**
 * @internal
 */
export declare const GetVoiceProfileDomainResponseFilterSensitiveLog: (obj: GetVoiceProfileDomainResponse) => any;
/**
 * @internal
 */
export declare const ListPhoneNumberOrdersResponseFilterSensitiveLog: (obj: ListPhoneNumberOrdersResponse) => any;
/**
 * @internal
 */
export declare const ListPhoneNumbersResponseFilterSensitiveLog: (obj: ListPhoneNumbersResponse) => any;
/**
 * @internal
 */
export declare const ListProxySessionsResponseFilterSensitiveLog: (obj: ListProxySessionsResponse) => any;
/**
 * @internal
 */
export declare const ListSipMediaApplicationsResponseFilterSensitiveLog: (obj: ListSipMediaApplicationsResponse) => any;
/**
 * @internal
 */
export declare const ListTagsForResourceRequestFilterSensitiveLog: (obj: ListTagsForResourceRequest) => any;
/**
 * @internal
 */
export declare const ListTagsForResourceResponseFilterSensitiveLog: (obj: ListTagsForResourceResponse) => any;
/**
 * @internal
 */
export declare const ListVoiceConnectorTerminationCredentialsResponseFilterSensitiveLog: (obj: ListVoiceConnectorTerminationCredentialsResponse) => any;
/**
 * @internal
 */
export declare const VoiceProfileDomainSummaryFilterSensitiveLog: (obj: VoiceProfileDomainSummary) => any;
/**
 * @internal
 */
export declare const ListVoiceProfileDomainsResponseFilterSensitiveLog: (obj: ListVoiceProfileDomainsResponse) => any;
/**
 * @internal
 */
export declare const VoiceProfileSummaryFilterSensitiveLog: (obj: VoiceProfileSummary) => any;
/**
 * @internal
 */
export declare const ListVoiceProfilesResponseFilterSensitiveLog: (obj: ListVoiceProfilesResponse) => any;
/**
 * @internal
 */
export declare const PutSipMediaApplicationAlexaSkillConfigurationRequestFilterSensitiveLog: (obj: PutSipMediaApplicationAlexaSkillConfigurationRequest) => any;
/**
 * @internal
 */
export declare const PutSipMediaApplicationAlexaSkillConfigurationResponseFilterSensitiveLog: (obj: PutSipMediaApplicationAlexaSkillConfigurationResponse) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorEmergencyCallingConfigurationRequestFilterSensitiveLog: (obj: PutVoiceConnectorEmergencyCallingConfigurationRequest) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorEmergencyCallingConfigurationResponseFilterSensitiveLog: (obj: PutVoiceConnectorEmergencyCallingConfigurationResponse) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorProxyRequestFilterSensitiveLog: (obj: PutVoiceConnectorProxyRequest) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorProxyResponseFilterSensitiveLog: (obj: PutVoiceConnectorProxyResponse) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorStreamingConfigurationRequestFilterSensitiveLog: (obj: PutVoiceConnectorStreamingConfigurationRequest) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorStreamingConfigurationResponseFilterSensitiveLog: (obj: PutVoiceConnectorStreamingConfigurationResponse) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorTerminationRequestFilterSensitiveLog: (obj: PutVoiceConnectorTerminationRequest) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorTerminationResponseFilterSensitiveLog: (obj: PutVoiceConnectorTerminationResponse) => any;
/**
 * @internal
 */
export declare const CredentialFilterSensitiveLog: (obj: Credential) => any;
/**
 * @internal
 */
export declare const PutVoiceConnectorTerminationCredentialsRequestFilterSensitiveLog: (obj: PutVoiceConnectorTerminationCredentialsRequest) => any;
/**
 * @internal
 */
export declare const RestorePhoneNumberRequestFilterSensitiveLog: (obj: RestorePhoneNumberRequest) => any;
/**
 * @internal
 */
export declare const RestorePhoneNumberResponseFilterSensitiveLog: (obj: RestorePhoneNumberResponse) => any;
/**
 * @internal
 */
export declare const SearchAvailablePhoneNumbersResponseFilterSensitiveLog: (obj: SearchAvailablePhoneNumbersResponse) => any;
/**
 * @internal
 */
export declare const TagResourceRequestFilterSensitiveLog: (obj: TagResourceRequest) => any;
/**
 * @internal
 */
export declare const UntagResourceRequestFilterSensitiveLog: (obj: UntagResourceRequest) => any;
/**
 * @internal
 */
export declare const UpdatePhoneNumberRequestFilterSensitiveLog: (obj: UpdatePhoneNumberRequest) => any;
/**
 * @internal
 */
export declare const UpdatePhoneNumberResponseFilterSensitiveLog: (obj: UpdatePhoneNumberResponse) => any;
/**
 * @internal
 */
export declare const UpdatePhoneNumberSettingsRequestFilterSensitiveLog: (obj: UpdatePhoneNumberSettingsRequest) => any;
/**
 * @internal
 */
export declare const UpdateProxySessionResponseFilterSensitiveLog: (obj: UpdateProxySessionResponse) => any;
/**
 * @internal
 */
export declare const UpdateSipMediaApplicationRequestFilterSensitiveLog: (obj: UpdateSipMediaApplicationRequest) => any;
/**
 * @internal
 */
export declare const UpdateSipMediaApplicationResponseFilterSensitiveLog: (obj: UpdateSipMediaApplicationResponse) => any;
/**
 * @internal
 */
export declare const UpdateSipMediaApplicationCallRequestFilterSensitiveLog: (obj: UpdateSipMediaApplicationCallRequest) => any;
/**
 * @internal
 */
export declare const UpdateVoiceProfileResponseFilterSensitiveLog: (obj: UpdateVoiceProfileResponse) => any;
/**
 * @internal
 */
export declare const UpdateVoiceProfileDomainResponseFilterSensitiveLog: (obj: UpdateVoiceProfileDomainResponse) => any;
/**
 * @internal
 */
export declare const ValidateE911AddressRequestFilterSensitiveLog: (obj: ValidateE911AddressRequest) => any;
/**
 * @internal
 */
export declare const ValidateE911AddressResponseFilterSensitiveLog: (obj: ValidateE911AddressResponse) => any;
