import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudWatchLogsClient";
import { UpdateAnomalyRequest } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link UpdateAnomalyCommand}.
 */
export interface UpdateAnomalyCommandInput extends UpdateAnomalyRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateAnomalyCommand}.
 */
export interface UpdateAnomalyCommandOutput extends __MetadataBearer {
}
declare const UpdateAnomalyCommand_base: {
    new (input: UpdateAnomalyCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateAnomalyCommandInput, UpdateAnomalyCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: UpdateAnomalyCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateAnomalyCommandInput, UpdateAnomalyCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Use this operation to <i>suppress</i> anomaly detection for a specified anomaly or pattern. If you suppress
 *        an anomaly, CloudWatch Logs won’t report new occurrences of that anomaly and won't
 *        update that anomaly
 *        with new data. If you suppress a pattern, CloudWatch Logs won’t report any anomalies related to that pattern.</p>
 *          <p>You must specify either <code>anomalyId</code> or <code>patternId</code>, but you can't specify both parameters in the
 *      same operation.</p>
 *          <p>If you have previously used this operation to suppress detection of a pattern or anomaly, you can use it again to cause
 *        CloudWatch Logs to end the suppression. To do this, use this operation and specify the anomaly or pattern to
 *      stop suppressing, and omit the <code>suppressionType</code> and <code>suppressionPeriod</code> parameters.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudWatchLogsClient, UpdateAnomalyCommand } from "@aws-sdk/client-cloudwatch-logs"; // ES Modules import
 * // const { CloudWatchLogsClient, UpdateAnomalyCommand } = require("@aws-sdk/client-cloudwatch-logs"); // CommonJS import
 * const client = new CloudWatchLogsClient(config);
 * const input = { // UpdateAnomalyRequest
 *   anomalyId: "STRING_VALUE",
 *   patternId: "STRING_VALUE",
 *   anomalyDetectorArn: "STRING_VALUE", // required
 *   suppressionType: "LIMITED" || "INFINITE",
 *   suppressionPeriod: { // SuppressionPeriod
 *     value: Number("int"),
 *     suppressionUnit: "SECONDS" || "MINUTES" || "HOURS",
 *   },
 * };
 * const command = new UpdateAnomalyCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdateAnomalyCommandInput - {@link UpdateAnomalyCommandInput}
 * @returns {@link UpdateAnomalyCommandOutput}
 * @see {@link UpdateAnomalyCommandInput} for command's `input` shape.
 * @see {@link UpdateAnomalyCommandOutput} for command's `response` shape.
 * @see {@link CloudWatchLogsClientResolvedConfig | config} for CloudWatchLogsClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>A parameter is specified incorrectly.</p>
 *
 * @throws {@link OperationAbortedException} (client fault)
 *  <p>Multiple concurrent requests to update the same resource were in conflict.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service cannot complete the request.</p>
 *
 * @throws {@link CloudWatchLogsServiceException}
 * <p>Base exception class for all service exceptions from CloudWatchLogs service.</p>
 *
 * @public
 */
export declare class UpdateAnomalyCommand extends UpdateAnomalyCommand_base {
}
