import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CloudWatchLogsClient";
import { UpdateLogAnomalyDetectorRequest } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link UpdateLogAnomalyDetectorCommand}.
 */
export interface UpdateLogAnomalyDetectorCommandInput extends UpdateLogAnomalyDetectorRequest {
}
/**
 * @public
 *
 * The output of {@link UpdateLogAnomalyDetectorCommand}.
 */
export interface UpdateLogAnomalyDetectorCommandOutput extends __MetadataBearer {
}
declare const UpdateLogAnomalyDetectorCommand_base: {
    new (input: UpdateLogAnomalyDetectorCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateLogAnomalyDetectorCommandInput, UpdateLogAnomalyDetectorCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: UpdateLogAnomalyDetectorCommandInput): import("@smithy/smithy-client").CommandImpl<UpdateLogAnomalyDetectorCommandInput, UpdateLogAnomalyDetectorCommandOutput, CloudWatchLogsClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Updates an existing log anomaly detector.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CloudWatchLogsClient, UpdateLogAnomalyDetectorCommand } from "@aws-sdk/client-cloudwatch-logs"; // ES Modules import
 * // const { CloudWatchLogsClient, UpdateLogAnomalyDetectorCommand } = require("@aws-sdk/client-cloudwatch-logs"); // CommonJS import
 * const client = new CloudWatchLogsClient(config);
 * const input = { // UpdateLogAnomalyDetectorRequest
 *   anomalyDetectorArn: "STRING_VALUE", // required
 *   evaluationFrequency: "ONE_MIN" || "FIVE_MIN" || "TEN_MIN" || "FIFTEEN_MIN" || "THIRTY_MIN" || "ONE_HOUR",
 *   filterPattern: "STRING_VALUE",
 *   anomalyVisibilityTime: Number("long"),
 *   enabled: true || false, // required
 * };
 * const command = new UpdateLogAnomalyDetectorCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param UpdateLogAnomalyDetectorCommandInput - {@link UpdateLogAnomalyDetectorCommandInput}
 * @returns {@link UpdateLogAnomalyDetectorCommandOutput}
 * @see {@link UpdateLogAnomalyDetectorCommandInput} for command's `input` shape.
 * @see {@link UpdateLogAnomalyDetectorCommandOutput} for command's `response` shape.
 * @see {@link CloudWatchLogsClientResolvedConfig | config} for CloudWatchLogsClient's `config` shape.
 *
 * @throws {@link InvalidParameterException} (client fault)
 *  <p>A parameter is specified incorrectly.</p>
 *
 * @throws {@link OperationAbortedException} (client fault)
 *  <p>Multiple concurrent requests to update the same resource were in conflict.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>The specified resource does not exist.</p>
 *
 * @throws {@link ServiceUnavailableException} (server fault)
 *  <p>The service cannot complete the request.</p>
 *
 * @throws {@link CloudWatchLogsServiceException}
 * <p>Base exception class for all service exceptions from CloudWatchLogs service.</p>
 *
 * @public
 */
export declare class UpdateLogAnomalyDetectorCommand extends UpdateLogAnomalyDetectorCommand_base {
}
