import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { KinesisVideoClientResolvedConfig } from "../KinesisVideoClient";
/**
 * @internal
 */
export interface KinesisVideoHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface KinesisVideoHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<KinesisVideoClientResolvedConfig, HandlerExecutionContext, KinesisVideoHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultKinesisVideoHttpAuthSchemeParametersProvider: (config: KinesisVideoClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<KinesisVideoHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface KinesisVideoHttpAuthSchemeProvider extends HttpAuthSchemeProvider<KinesisVideoHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultKinesisVideoHttpAuthSchemeProvider: KinesisVideoHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: KinesisVideoHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: KinesisVideoHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
